contact

package
v0.0.0-...-2dc66f2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 18, 2023 License: MIT Imports: 5 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the contact type in the database.
	Label = "contact"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldCreateTime holds the string denoting the create_time field in the database.
	FieldCreateTime = "create_time"
	// FieldUpdateTime holds the string denoting the update_time field in the database.
	FieldUpdateTime = "update_time"
	// FieldOwnerID holds the string denoting the owner_id field in the database.
	FieldOwnerID = "owner_id"
	// FieldAccountNumber holds the string denoting the account_number field in the database.
	FieldAccountNumber = "account_number"
	// FieldSuggestName holds the string denoting the suggest_name field in the database.
	FieldSuggestName = "suggest_name"
	// FieldBankName holds the string denoting the bank_name field in the database.
	FieldBankName = "bank_name"
	// EdgeOwner holds the string denoting the owner edge name in mutations.
	EdgeOwner = "owner"
	// Table holds the table name of the contact in the database.
	Table = "contacts"
	// OwnerTable is the table that holds the owner relation/edge.
	OwnerTable = "contacts"
	// OwnerInverseTable is the table name for the Customer entity.
	// It exists in this package in order to avoid circular dependency with the "customer" package.
	OwnerInverseTable = "customers"
	// OwnerColumn is the table column denoting the owner relation/edge.
	OwnerColumn = "owner_id"
)

Variables

var (
	// DefaultCreateTime holds the default value on creation for the "create_time" field.
	DefaultCreateTime func() time.Time
	// DefaultUpdateTime holds the default value on creation for the "update_time" field.
	DefaultUpdateTime func() time.Time
	// UpdateDefaultUpdateTime holds the default value on update for the "update_time" field.
	UpdateDefaultUpdateTime func() time.Time
	// AccountNumberValidator is a validator for the "account_number" field. It is called by the builders before save.
	AccountNumberValidator func(string) error
	// SuggestNameValidator is a validator for the "suggest_name" field. It is called by the builders before save.
	SuggestNameValidator func(string) error
	// DefaultID holds the default value on creation for the "id" field.
	DefaultID func() uuid.UUID
)

Columns holds all SQL columns for contact fields.

Functions

func AccountNumber

func AccountNumber(v string) predicate.Contact

AccountNumber applies equality check predicate on the "account_number" field. It's identical to AccountNumberEQ.

func AccountNumberContains

func AccountNumberContains(v string) predicate.Contact

AccountNumberContains applies the Contains predicate on the "account_number" field.

func AccountNumberContainsFold

func AccountNumberContainsFold(v string) predicate.Contact

AccountNumberContainsFold applies the ContainsFold predicate on the "account_number" field.

func AccountNumberEQ

func AccountNumberEQ(v string) predicate.Contact

AccountNumberEQ applies the EQ predicate on the "account_number" field.

func AccountNumberEqualFold

func AccountNumberEqualFold(v string) predicate.Contact

AccountNumberEqualFold applies the EqualFold predicate on the "account_number" field.

func AccountNumberGT

func AccountNumberGT(v string) predicate.Contact

AccountNumberGT applies the GT predicate on the "account_number" field.

func AccountNumberGTE

func AccountNumberGTE(v string) predicate.Contact

AccountNumberGTE applies the GTE predicate on the "account_number" field.

func AccountNumberHasPrefix

func AccountNumberHasPrefix(v string) predicate.Contact

AccountNumberHasPrefix applies the HasPrefix predicate on the "account_number" field.

func AccountNumberHasSuffix

func AccountNumberHasSuffix(v string) predicate.Contact

AccountNumberHasSuffix applies the HasSuffix predicate on the "account_number" field.

func AccountNumberIn

func AccountNumberIn(vs ...string) predicate.Contact

AccountNumberIn applies the In predicate on the "account_number" field.

func AccountNumberLT

func AccountNumberLT(v string) predicate.Contact

AccountNumberLT applies the LT predicate on the "account_number" field.

func AccountNumberLTE

func AccountNumberLTE(v string) predicate.Contact

AccountNumberLTE applies the LTE predicate on the "account_number" field.

func AccountNumberNEQ

func AccountNumberNEQ(v string) predicate.Contact

AccountNumberNEQ applies the NEQ predicate on the "account_number" field.

func AccountNumberNotIn

func AccountNumberNotIn(vs ...string) predicate.Contact

AccountNumberNotIn applies the NotIn predicate on the "account_number" field.

func And

func And(predicates ...predicate.Contact) predicate.Contact

And groups predicates with the AND operator between them.

func BankName

func BankName(v string) predicate.Contact

BankName applies equality check predicate on the "bank_name" field. It's identical to BankNameEQ.

func BankNameContains

func BankNameContains(v string) predicate.Contact

BankNameContains applies the Contains predicate on the "bank_name" field.

func BankNameContainsFold

func BankNameContainsFold(v string) predicate.Contact

BankNameContainsFold applies the ContainsFold predicate on the "bank_name" field.

func BankNameEQ

func BankNameEQ(v string) predicate.Contact

BankNameEQ applies the EQ predicate on the "bank_name" field.

func BankNameEqualFold

func BankNameEqualFold(v string) predicate.Contact

BankNameEqualFold applies the EqualFold predicate on the "bank_name" field.

func BankNameGT

func BankNameGT(v string) predicate.Contact

BankNameGT applies the GT predicate on the "bank_name" field.

func BankNameGTE

func BankNameGTE(v string) predicate.Contact

BankNameGTE applies the GTE predicate on the "bank_name" field.

func BankNameHasPrefix

func BankNameHasPrefix(v string) predicate.Contact

BankNameHasPrefix applies the HasPrefix predicate on the "bank_name" field.

func BankNameHasSuffix

func BankNameHasSuffix(v string) predicate.Contact

BankNameHasSuffix applies the HasSuffix predicate on the "bank_name" field.

func BankNameIn

func BankNameIn(vs ...string) predicate.Contact

BankNameIn applies the In predicate on the "bank_name" field.

func BankNameLT

func BankNameLT(v string) predicate.Contact

BankNameLT applies the LT predicate on the "bank_name" field.

func BankNameLTE

func BankNameLTE(v string) predicate.Contact

BankNameLTE applies the LTE predicate on the "bank_name" field.

func BankNameNEQ

func BankNameNEQ(v string) predicate.Contact

BankNameNEQ applies the NEQ predicate on the "bank_name" field.

func BankNameNotIn

func BankNameNotIn(vs ...string) predicate.Contact

BankNameNotIn applies the NotIn predicate on the "bank_name" field.

func CreateTime

func CreateTime(v time.Time) predicate.Contact

CreateTime applies equality check predicate on the "create_time" field. It's identical to CreateTimeEQ.

func CreateTimeEQ

func CreateTimeEQ(v time.Time) predicate.Contact

CreateTimeEQ applies the EQ predicate on the "create_time" field.

func CreateTimeGT

func CreateTimeGT(v time.Time) predicate.Contact

CreateTimeGT applies the GT predicate on the "create_time" field.

func CreateTimeGTE

func CreateTimeGTE(v time.Time) predicate.Contact

CreateTimeGTE applies the GTE predicate on the "create_time" field.

func CreateTimeIn

func CreateTimeIn(vs ...time.Time) predicate.Contact

CreateTimeIn applies the In predicate on the "create_time" field.

func CreateTimeLT

func CreateTimeLT(v time.Time) predicate.Contact

CreateTimeLT applies the LT predicate on the "create_time" field.

func CreateTimeLTE

func CreateTimeLTE(v time.Time) predicate.Contact

CreateTimeLTE applies the LTE predicate on the "create_time" field.

func CreateTimeNEQ

func CreateTimeNEQ(v time.Time) predicate.Contact

CreateTimeNEQ applies the NEQ predicate on the "create_time" field.

func CreateTimeNotIn

func CreateTimeNotIn(vs ...time.Time) predicate.Contact

CreateTimeNotIn applies the NotIn predicate on the "create_time" field.

func HasOwner

func HasOwner() predicate.Contact

HasOwner applies the HasEdge predicate on the "owner" edge.

func HasOwnerWith

func HasOwnerWith(preds ...predicate.Customer) predicate.Contact

HasOwnerWith applies the HasEdge predicate on the "owner" edge with a given conditions (other predicates).

func ID

func ID(id uuid.UUID) predicate.Contact

ID filters vertices based on their ID field.

func IDEQ

func IDEQ(id uuid.UUID) predicate.Contact

IDEQ applies the EQ predicate on the ID field.

func IDGT

func IDGT(id uuid.UUID) predicate.Contact

IDGT applies the GT predicate on the ID field.

func IDGTE

func IDGTE(id uuid.UUID) predicate.Contact

IDGTE applies the GTE predicate on the ID field.

func IDIn

func IDIn(ids ...uuid.UUID) predicate.Contact

IDIn applies the In predicate on the ID field.

func IDLT

func IDLT(id uuid.UUID) predicate.Contact

IDLT applies the LT predicate on the ID field.

func IDLTE

func IDLTE(id uuid.UUID) predicate.Contact

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

func IDNEQ(id uuid.UUID) predicate.Contact

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...uuid.UUID) predicate.Contact

IDNotIn applies the NotIn predicate on the ID field.

func Not

Not applies the not operator on the given predicate.

func Or

func Or(predicates ...predicate.Contact) predicate.Contact

Or groups predicates with the OR operator between them.

func OwnerID

func OwnerID(v uuid.UUID) predicate.Contact

OwnerID applies equality check predicate on the "owner_id" field. It's identical to OwnerIDEQ.

func OwnerIDEQ

func OwnerIDEQ(v uuid.UUID) predicate.Contact

OwnerIDEQ applies the EQ predicate on the "owner_id" field.

func OwnerIDIn

func OwnerIDIn(vs ...uuid.UUID) predicate.Contact

OwnerIDIn applies the In predicate on the "owner_id" field.

func OwnerIDNEQ

func OwnerIDNEQ(v uuid.UUID) predicate.Contact

OwnerIDNEQ applies the NEQ predicate on the "owner_id" field.

func OwnerIDNotIn

func OwnerIDNotIn(vs ...uuid.UUID) predicate.Contact

OwnerIDNotIn applies the NotIn predicate on the "owner_id" field.

func SuggestName

func SuggestName(v string) predicate.Contact

SuggestName applies equality check predicate on the "suggest_name" field. It's identical to SuggestNameEQ.

func SuggestNameContains

func SuggestNameContains(v string) predicate.Contact

SuggestNameContains applies the Contains predicate on the "suggest_name" field.

func SuggestNameContainsFold

func SuggestNameContainsFold(v string) predicate.Contact

SuggestNameContainsFold applies the ContainsFold predicate on the "suggest_name" field.

func SuggestNameEQ

func SuggestNameEQ(v string) predicate.Contact

SuggestNameEQ applies the EQ predicate on the "suggest_name" field.

func SuggestNameEqualFold

func SuggestNameEqualFold(v string) predicate.Contact

SuggestNameEqualFold applies the EqualFold predicate on the "suggest_name" field.

func SuggestNameGT

func SuggestNameGT(v string) predicate.Contact

SuggestNameGT applies the GT predicate on the "suggest_name" field.

func SuggestNameGTE

func SuggestNameGTE(v string) predicate.Contact

SuggestNameGTE applies the GTE predicate on the "suggest_name" field.

func SuggestNameHasPrefix

func SuggestNameHasPrefix(v string) predicate.Contact

SuggestNameHasPrefix applies the HasPrefix predicate on the "suggest_name" field.

func SuggestNameHasSuffix

func SuggestNameHasSuffix(v string) predicate.Contact

SuggestNameHasSuffix applies the HasSuffix predicate on the "suggest_name" field.

func SuggestNameIn

func SuggestNameIn(vs ...string) predicate.Contact

SuggestNameIn applies the In predicate on the "suggest_name" field.

func SuggestNameLT

func SuggestNameLT(v string) predicate.Contact

SuggestNameLT applies the LT predicate on the "suggest_name" field.

func SuggestNameLTE

func SuggestNameLTE(v string) predicate.Contact

SuggestNameLTE applies the LTE predicate on the "suggest_name" field.

func SuggestNameNEQ

func SuggestNameNEQ(v string) predicate.Contact

SuggestNameNEQ applies the NEQ predicate on the "suggest_name" field.

func SuggestNameNotIn

func SuggestNameNotIn(vs ...string) predicate.Contact

SuggestNameNotIn applies the NotIn predicate on the "suggest_name" field.

func UpdateTime

func UpdateTime(v time.Time) predicate.Contact

UpdateTime applies equality check predicate on the "update_time" field. It's identical to UpdateTimeEQ.

func UpdateTimeEQ

func UpdateTimeEQ(v time.Time) predicate.Contact

UpdateTimeEQ applies the EQ predicate on the "update_time" field.

func UpdateTimeGT

func UpdateTimeGT(v time.Time) predicate.Contact

UpdateTimeGT applies the GT predicate on the "update_time" field.

func UpdateTimeGTE

func UpdateTimeGTE(v time.Time) predicate.Contact

UpdateTimeGTE applies the GTE predicate on the "update_time" field.

func UpdateTimeIn

func UpdateTimeIn(vs ...time.Time) predicate.Contact

UpdateTimeIn applies the In predicate on the "update_time" field.

func UpdateTimeLT

func UpdateTimeLT(v time.Time) predicate.Contact

UpdateTimeLT applies the LT predicate on the "update_time" field.

func UpdateTimeLTE

func UpdateTimeLTE(v time.Time) predicate.Contact

UpdateTimeLTE applies the LTE predicate on the "update_time" field.

func UpdateTimeNEQ

func UpdateTimeNEQ(v time.Time) predicate.Contact

UpdateTimeNEQ applies the NEQ predicate on the "update_time" field.

func UpdateTimeNotIn

func UpdateTimeNotIn(vs ...time.Time) predicate.Contact

UpdateTimeNotIn applies the NotIn predicate on the "update_time" field.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

Types

This section is empty.

Jump to