customer

package
v0.0.0-...-2dc66f2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 18, 2023 License: MIT Imports: 5 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the customer type in the database.
	Label = "customer"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldCreateTime holds the string denoting the create_time field in the database.
	FieldCreateTime = "create_time"
	// FieldUpdateTime holds the string denoting the update_time field in the database.
	FieldUpdateTime = "update_time"
	// FieldJwtTokenKey holds the string denoting the jwt_token_key field in the database.
	FieldJwtTokenKey = "jwt_token_key"
	// FieldPassword holds the string denoting the password field in the database.
	FieldPassword = "password"
	// FieldUsername holds the string denoting the username field in the database.
	FieldUsername = "username"
	// FieldFirstName holds the string denoting the first_name field in the database.
	FieldFirstName = "first_name"
	// FieldLastName holds the string denoting the last_name field in the database.
	FieldLastName = "last_name"
	// FieldPhoneNumber holds the string denoting the phone_number field in the database.
	FieldPhoneNumber = "phone_number"
	// FieldEmail holds the string denoting the email field in the database.
	FieldEmail = "email"
	// FieldIsActive holds the string denoting the is_active field in the database.
	FieldIsActive = "is_active"
	// EdgeBankAccounts holds the string denoting the bank_accounts edge name in mutations.
	EdgeBankAccounts = "bank_accounts"
	// EdgeContacts holds the string denoting the contacts edge name in mutations.
	EdgeContacts = "contacts"
	// Table holds the table name of the customer in the database.
	Table = "customers"
	// BankAccountsTable is the table that holds the bank_accounts relation/edge.
	BankAccountsTable = "bank_accounts"
	// BankAccountsInverseTable is the table name for the BankAccount entity.
	// It exists in this package in order to avoid circular dependency with the "bankaccount" package.
	BankAccountsInverseTable = "bank_accounts"
	// BankAccountsColumn is the table column denoting the bank_accounts relation/edge.
	BankAccountsColumn = "customer_id"
	// ContactsTable is the table that holds the contacts relation/edge.
	ContactsTable = "contacts"
	// ContactsInverseTable is the table name for the Contact entity.
	// It exists in this package in order to avoid circular dependency with the "contact" package.
	ContactsInverseTable = "contacts"
	// ContactsColumn is the table column denoting the contacts relation/edge.
	ContactsColumn = "owner_id"
)

Variables

var (
	// DefaultCreateTime holds the default value on creation for the "create_time" field.
	DefaultCreateTime func() time.Time
	// DefaultUpdateTime holds the default value on creation for the "update_time" field.
	DefaultUpdateTime func() time.Time
	// UpdateDefaultUpdateTime holds the default value on update for the "update_time" field.
	UpdateDefaultUpdateTime func() time.Time
	// DefaultJwtTokenKey holds the default value on creation for the "jwt_token_key" field.
	DefaultJwtTokenKey func() string
	// PasswordValidator is a validator for the "password" field. It is called by the builders before save.
	PasswordValidator func(string) error
	// UsernameValidator is a validator for the "username" field. It is called by the builders before save.
	UsernameValidator func(string) error
	// DefaultFirstName holds the default value on creation for the "first_name" field.
	DefaultFirstName string
	// FirstNameValidator is a validator for the "first_name" field. It is called by the builders before save.
	FirstNameValidator func(string) error
	// DefaultLastName holds the default value on creation for the "last_name" field.
	DefaultLastName string
	// LastNameValidator is a validator for the "last_name" field. It is called by the builders before save.
	LastNameValidator func(string) error
	// PhoneNumberValidator is a validator for the "phone_number" field. It is called by the builders before save.
	PhoneNumberValidator func(string) error
	// EmailValidator is a validator for the "email" field. It is called by the builders before save.
	EmailValidator func(string) error
	// DefaultIsActive holds the default value on creation for the "is_active" field.
	DefaultIsActive bool
	// DefaultID holds the default value on creation for the "id" field.
	DefaultID func() uuid.UUID
)

Columns holds all SQL columns for customer fields.

Functions

func And

func And(predicates ...predicate.Customer) predicate.Customer

And groups predicates with the AND operator between them.

func CreateTime

func CreateTime(v time.Time) predicate.Customer

CreateTime applies equality check predicate on the "create_time" field. It's identical to CreateTimeEQ.

func CreateTimeEQ

func CreateTimeEQ(v time.Time) predicate.Customer

CreateTimeEQ applies the EQ predicate on the "create_time" field.

func CreateTimeGT

func CreateTimeGT(v time.Time) predicate.Customer

CreateTimeGT applies the GT predicate on the "create_time" field.

func CreateTimeGTE

func CreateTimeGTE(v time.Time) predicate.Customer

CreateTimeGTE applies the GTE predicate on the "create_time" field.

func CreateTimeIn

func CreateTimeIn(vs ...time.Time) predicate.Customer

CreateTimeIn applies the In predicate on the "create_time" field.

func CreateTimeLT

func CreateTimeLT(v time.Time) predicate.Customer

CreateTimeLT applies the LT predicate on the "create_time" field.

func CreateTimeLTE

func CreateTimeLTE(v time.Time) predicate.Customer

CreateTimeLTE applies the LTE predicate on the "create_time" field.

func CreateTimeNEQ

func CreateTimeNEQ(v time.Time) predicate.Customer

CreateTimeNEQ applies the NEQ predicate on the "create_time" field.

func CreateTimeNotIn

func CreateTimeNotIn(vs ...time.Time) predicate.Customer

CreateTimeNotIn applies the NotIn predicate on the "create_time" field.

func Email

func Email(v string) predicate.Customer

Email applies equality check predicate on the "email" field. It's identical to EmailEQ.

func EmailContains

func EmailContains(v string) predicate.Customer

EmailContains applies the Contains predicate on the "email" field.

func EmailContainsFold

func EmailContainsFold(v string) predicate.Customer

EmailContainsFold applies the ContainsFold predicate on the "email" field.

func EmailEQ

func EmailEQ(v string) predicate.Customer

EmailEQ applies the EQ predicate on the "email" field.

func EmailEqualFold

func EmailEqualFold(v string) predicate.Customer

EmailEqualFold applies the EqualFold predicate on the "email" field.

func EmailGT

func EmailGT(v string) predicate.Customer

EmailGT applies the GT predicate on the "email" field.

func EmailGTE

func EmailGTE(v string) predicate.Customer

EmailGTE applies the GTE predicate on the "email" field.

func EmailHasPrefix

func EmailHasPrefix(v string) predicate.Customer

EmailHasPrefix applies the HasPrefix predicate on the "email" field.

func EmailHasSuffix

func EmailHasSuffix(v string) predicate.Customer

EmailHasSuffix applies the HasSuffix predicate on the "email" field.

func EmailIn

func EmailIn(vs ...string) predicate.Customer

EmailIn applies the In predicate on the "email" field.

func EmailLT

func EmailLT(v string) predicate.Customer

EmailLT applies the LT predicate on the "email" field.

func EmailLTE

func EmailLTE(v string) predicate.Customer

EmailLTE applies the LTE predicate on the "email" field.

func EmailNEQ

func EmailNEQ(v string) predicate.Customer

EmailNEQ applies the NEQ predicate on the "email" field.

func EmailNotIn

func EmailNotIn(vs ...string) predicate.Customer

EmailNotIn applies the NotIn predicate on the "email" field.

func FirstName

func FirstName(v string) predicate.Customer

FirstName applies equality check predicate on the "first_name" field. It's identical to FirstNameEQ.

func FirstNameContains

func FirstNameContains(v string) predicate.Customer

FirstNameContains applies the Contains predicate on the "first_name" field.

func FirstNameContainsFold

func FirstNameContainsFold(v string) predicate.Customer

FirstNameContainsFold applies the ContainsFold predicate on the "first_name" field.

func FirstNameEQ

func FirstNameEQ(v string) predicate.Customer

FirstNameEQ applies the EQ predicate on the "first_name" field.

func FirstNameEqualFold

func FirstNameEqualFold(v string) predicate.Customer

FirstNameEqualFold applies the EqualFold predicate on the "first_name" field.

func FirstNameGT

func FirstNameGT(v string) predicate.Customer

FirstNameGT applies the GT predicate on the "first_name" field.

func FirstNameGTE

func FirstNameGTE(v string) predicate.Customer

FirstNameGTE applies the GTE predicate on the "first_name" field.

func FirstNameHasPrefix

func FirstNameHasPrefix(v string) predicate.Customer

FirstNameHasPrefix applies the HasPrefix predicate on the "first_name" field.

func FirstNameHasSuffix

func FirstNameHasSuffix(v string) predicate.Customer

FirstNameHasSuffix applies the HasSuffix predicate on the "first_name" field.

func FirstNameIn

func FirstNameIn(vs ...string) predicate.Customer

FirstNameIn applies the In predicate on the "first_name" field.

func FirstNameIsNil

func FirstNameIsNil() predicate.Customer

FirstNameIsNil applies the IsNil predicate on the "first_name" field.

func FirstNameLT

func FirstNameLT(v string) predicate.Customer

FirstNameLT applies the LT predicate on the "first_name" field.

func FirstNameLTE

func FirstNameLTE(v string) predicate.Customer

FirstNameLTE applies the LTE predicate on the "first_name" field.

func FirstNameNEQ

func FirstNameNEQ(v string) predicate.Customer

FirstNameNEQ applies the NEQ predicate on the "first_name" field.

func FirstNameNotIn

func FirstNameNotIn(vs ...string) predicate.Customer

FirstNameNotIn applies the NotIn predicate on the "first_name" field.

func FirstNameNotNil

func FirstNameNotNil() predicate.Customer

FirstNameNotNil applies the NotNil predicate on the "first_name" field.

func HasBankAccounts

func HasBankAccounts() predicate.Customer

HasBankAccounts applies the HasEdge predicate on the "bank_accounts" edge.

func HasBankAccountsWith

func HasBankAccountsWith(preds ...predicate.BankAccount) predicate.Customer

HasBankAccountsWith applies the HasEdge predicate on the "bank_accounts" edge with a given conditions (other predicates).

func HasContacts

func HasContacts() predicate.Customer

HasContacts applies the HasEdge predicate on the "contacts" edge.

func HasContactsWith

func HasContactsWith(preds ...predicate.Contact) predicate.Customer

HasContactsWith applies the HasEdge predicate on the "contacts" edge with a given conditions (other predicates).

func ID

func ID(id uuid.UUID) predicate.Customer

ID filters vertices based on their ID field.

func IDEQ

func IDEQ(id uuid.UUID) predicate.Customer

IDEQ applies the EQ predicate on the ID field.

func IDGT

func IDGT(id uuid.UUID) predicate.Customer

IDGT applies the GT predicate on the ID field.

func IDGTE

func IDGTE(id uuid.UUID) predicate.Customer

IDGTE applies the GTE predicate on the ID field.

func IDIn

func IDIn(ids ...uuid.UUID) predicate.Customer

IDIn applies the In predicate on the ID field.

func IDLT

func IDLT(id uuid.UUID) predicate.Customer

IDLT applies the LT predicate on the ID field.

func IDLTE

func IDLTE(id uuid.UUID) predicate.Customer

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

func IDNEQ(id uuid.UUID) predicate.Customer

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...uuid.UUID) predicate.Customer

IDNotIn applies the NotIn predicate on the ID field.

func IsActive

func IsActive(v bool) predicate.Customer

IsActive applies equality check predicate on the "is_active" field. It's identical to IsActiveEQ.

func IsActiveEQ

func IsActiveEQ(v bool) predicate.Customer

IsActiveEQ applies the EQ predicate on the "is_active" field.

func IsActiveIsNil

func IsActiveIsNil() predicate.Customer

IsActiveIsNil applies the IsNil predicate on the "is_active" field.

func IsActiveNEQ

func IsActiveNEQ(v bool) predicate.Customer

IsActiveNEQ applies the NEQ predicate on the "is_active" field.

func IsActiveNotNil

func IsActiveNotNil() predicate.Customer

IsActiveNotNil applies the NotNil predicate on the "is_active" field.

func JwtTokenKey

func JwtTokenKey(v string) predicate.Customer

JwtTokenKey applies equality check predicate on the "jwt_token_key" field. It's identical to JwtTokenKeyEQ.

func JwtTokenKeyContains

func JwtTokenKeyContains(v string) predicate.Customer

JwtTokenKeyContains applies the Contains predicate on the "jwt_token_key" field.

func JwtTokenKeyContainsFold

func JwtTokenKeyContainsFold(v string) predicate.Customer

JwtTokenKeyContainsFold applies the ContainsFold predicate on the "jwt_token_key" field.

func JwtTokenKeyEQ

func JwtTokenKeyEQ(v string) predicate.Customer

JwtTokenKeyEQ applies the EQ predicate on the "jwt_token_key" field.

func JwtTokenKeyEqualFold

func JwtTokenKeyEqualFold(v string) predicate.Customer

JwtTokenKeyEqualFold applies the EqualFold predicate on the "jwt_token_key" field.

func JwtTokenKeyGT

func JwtTokenKeyGT(v string) predicate.Customer

JwtTokenKeyGT applies the GT predicate on the "jwt_token_key" field.

func JwtTokenKeyGTE

func JwtTokenKeyGTE(v string) predicate.Customer

JwtTokenKeyGTE applies the GTE predicate on the "jwt_token_key" field.

func JwtTokenKeyHasPrefix

func JwtTokenKeyHasPrefix(v string) predicate.Customer

JwtTokenKeyHasPrefix applies the HasPrefix predicate on the "jwt_token_key" field.

func JwtTokenKeyHasSuffix

func JwtTokenKeyHasSuffix(v string) predicate.Customer

JwtTokenKeyHasSuffix applies the HasSuffix predicate on the "jwt_token_key" field.

func JwtTokenKeyIn

func JwtTokenKeyIn(vs ...string) predicate.Customer

JwtTokenKeyIn applies the In predicate on the "jwt_token_key" field.

func JwtTokenKeyIsNil

func JwtTokenKeyIsNil() predicate.Customer

JwtTokenKeyIsNil applies the IsNil predicate on the "jwt_token_key" field.

func JwtTokenKeyLT

func JwtTokenKeyLT(v string) predicate.Customer

JwtTokenKeyLT applies the LT predicate on the "jwt_token_key" field.

func JwtTokenKeyLTE

func JwtTokenKeyLTE(v string) predicate.Customer

JwtTokenKeyLTE applies the LTE predicate on the "jwt_token_key" field.

func JwtTokenKeyNEQ

func JwtTokenKeyNEQ(v string) predicate.Customer

JwtTokenKeyNEQ applies the NEQ predicate on the "jwt_token_key" field.

func JwtTokenKeyNotIn

func JwtTokenKeyNotIn(vs ...string) predicate.Customer

JwtTokenKeyNotIn applies the NotIn predicate on the "jwt_token_key" field.

func JwtTokenKeyNotNil

func JwtTokenKeyNotNil() predicate.Customer

JwtTokenKeyNotNil applies the NotNil predicate on the "jwt_token_key" field.

func LastName

func LastName(v string) predicate.Customer

LastName applies equality check predicate on the "last_name" field. It's identical to LastNameEQ.

func LastNameContains

func LastNameContains(v string) predicate.Customer

LastNameContains applies the Contains predicate on the "last_name" field.

func LastNameContainsFold

func LastNameContainsFold(v string) predicate.Customer

LastNameContainsFold applies the ContainsFold predicate on the "last_name" field.

func LastNameEQ

func LastNameEQ(v string) predicate.Customer

LastNameEQ applies the EQ predicate on the "last_name" field.

func LastNameEqualFold

func LastNameEqualFold(v string) predicate.Customer

LastNameEqualFold applies the EqualFold predicate on the "last_name" field.

func LastNameGT

func LastNameGT(v string) predicate.Customer

LastNameGT applies the GT predicate on the "last_name" field.

func LastNameGTE

func LastNameGTE(v string) predicate.Customer

LastNameGTE applies the GTE predicate on the "last_name" field.

func LastNameHasPrefix

func LastNameHasPrefix(v string) predicate.Customer

LastNameHasPrefix applies the HasPrefix predicate on the "last_name" field.

func LastNameHasSuffix

func LastNameHasSuffix(v string) predicate.Customer

LastNameHasSuffix applies the HasSuffix predicate on the "last_name" field.

func LastNameIn

func LastNameIn(vs ...string) predicate.Customer

LastNameIn applies the In predicate on the "last_name" field.

func LastNameIsNil

func LastNameIsNil() predicate.Customer

LastNameIsNil applies the IsNil predicate on the "last_name" field.

func LastNameLT

func LastNameLT(v string) predicate.Customer

LastNameLT applies the LT predicate on the "last_name" field.

func LastNameLTE

func LastNameLTE(v string) predicate.Customer

LastNameLTE applies the LTE predicate on the "last_name" field.

func LastNameNEQ

func LastNameNEQ(v string) predicate.Customer

LastNameNEQ applies the NEQ predicate on the "last_name" field.

func LastNameNotIn

func LastNameNotIn(vs ...string) predicate.Customer

LastNameNotIn applies the NotIn predicate on the "last_name" field.

func LastNameNotNil

func LastNameNotNil() predicate.Customer

LastNameNotNil applies the NotNil predicate on the "last_name" field.

func Not

Not applies the not operator on the given predicate.

func Or

func Or(predicates ...predicate.Customer) predicate.Customer

Or groups predicates with the OR operator between them.

func Password

func Password(v string) predicate.Customer

Password applies equality check predicate on the "password" field. It's identical to PasswordEQ.

func PasswordContains

func PasswordContains(v string) predicate.Customer

PasswordContains applies the Contains predicate on the "password" field.

func PasswordContainsFold

func PasswordContainsFold(v string) predicate.Customer

PasswordContainsFold applies the ContainsFold predicate on the "password" field.

func PasswordEQ

func PasswordEQ(v string) predicate.Customer

PasswordEQ applies the EQ predicate on the "password" field.

func PasswordEqualFold

func PasswordEqualFold(v string) predicate.Customer

PasswordEqualFold applies the EqualFold predicate on the "password" field.

func PasswordGT

func PasswordGT(v string) predicate.Customer

PasswordGT applies the GT predicate on the "password" field.

func PasswordGTE

func PasswordGTE(v string) predicate.Customer

PasswordGTE applies the GTE predicate on the "password" field.

func PasswordHasPrefix

func PasswordHasPrefix(v string) predicate.Customer

PasswordHasPrefix applies the HasPrefix predicate on the "password" field.

func PasswordHasSuffix

func PasswordHasSuffix(v string) predicate.Customer

PasswordHasSuffix applies the HasSuffix predicate on the "password" field.

func PasswordIn

func PasswordIn(vs ...string) predicate.Customer

PasswordIn applies the In predicate on the "password" field.

func PasswordIsNil

func PasswordIsNil() predicate.Customer

PasswordIsNil applies the IsNil predicate on the "password" field.

func PasswordLT

func PasswordLT(v string) predicate.Customer

PasswordLT applies the LT predicate on the "password" field.

func PasswordLTE

func PasswordLTE(v string) predicate.Customer

PasswordLTE applies the LTE predicate on the "password" field.

func PasswordNEQ

func PasswordNEQ(v string) predicate.Customer

PasswordNEQ applies the NEQ predicate on the "password" field.

func PasswordNotIn

func PasswordNotIn(vs ...string) predicate.Customer

PasswordNotIn applies the NotIn predicate on the "password" field.

func PasswordNotNil

func PasswordNotNil() predicate.Customer

PasswordNotNil applies the NotNil predicate on the "password" field.

func PhoneNumber

func PhoneNumber(v string) predicate.Customer

PhoneNumber applies equality check predicate on the "phone_number" field. It's identical to PhoneNumberEQ.

func PhoneNumberContains

func PhoneNumberContains(v string) predicate.Customer

PhoneNumberContains applies the Contains predicate on the "phone_number" field.

func PhoneNumberContainsFold

func PhoneNumberContainsFold(v string) predicate.Customer

PhoneNumberContainsFold applies the ContainsFold predicate on the "phone_number" field.

func PhoneNumberEQ

func PhoneNumberEQ(v string) predicate.Customer

PhoneNumberEQ applies the EQ predicate on the "phone_number" field.

func PhoneNumberEqualFold

func PhoneNumberEqualFold(v string) predicate.Customer

PhoneNumberEqualFold applies the EqualFold predicate on the "phone_number" field.

func PhoneNumberGT

func PhoneNumberGT(v string) predicate.Customer

PhoneNumberGT applies the GT predicate on the "phone_number" field.

func PhoneNumberGTE

func PhoneNumberGTE(v string) predicate.Customer

PhoneNumberGTE applies the GTE predicate on the "phone_number" field.

func PhoneNumberHasPrefix

func PhoneNumberHasPrefix(v string) predicate.Customer

PhoneNumberHasPrefix applies the HasPrefix predicate on the "phone_number" field.

func PhoneNumberHasSuffix

func PhoneNumberHasSuffix(v string) predicate.Customer

PhoneNumberHasSuffix applies the HasSuffix predicate on the "phone_number" field.

func PhoneNumberIn

func PhoneNumberIn(vs ...string) predicate.Customer

PhoneNumberIn applies the In predicate on the "phone_number" field.

func PhoneNumberLT

func PhoneNumberLT(v string) predicate.Customer

PhoneNumberLT applies the LT predicate on the "phone_number" field.

func PhoneNumberLTE

func PhoneNumberLTE(v string) predicate.Customer

PhoneNumberLTE applies the LTE predicate on the "phone_number" field.

func PhoneNumberNEQ

func PhoneNumberNEQ(v string) predicate.Customer

PhoneNumberNEQ applies the NEQ predicate on the "phone_number" field.

func PhoneNumberNotIn

func PhoneNumberNotIn(vs ...string) predicate.Customer

PhoneNumberNotIn applies the NotIn predicate on the "phone_number" field.

func UpdateTime

func UpdateTime(v time.Time) predicate.Customer

UpdateTime applies equality check predicate on the "update_time" field. It's identical to UpdateTimeEQ.

func UpdateTimeEQ

func UpdateTimeEQ(v time.Time) predicate.Customer

UpdateTimeEQ applies the EQ predicate on the "update_time" field.

func UpdateTimeGT

func UpdateTimeGT(v time.Time) predicate.Customer

UpdateTimeGT applies the GT predicate on the "update_time" field.

func UpdateTimeGTE

func UpdateTimeGTE(v time.Time) predicate.Customer

UpdateTimeGTE applies the GTE predicate on the "update_time" field.

func UpdateTimeIn

func UpdateTimeIn(vs ...time.Time) predicate.Customer

UpdateTimeIn applies the In predicate on the "update_time" field.

func UpdateTimeLT

func UpdateTimeLT(v time.Time) predicate.Customer

UpdateTimeLT applies the LT predicate on the "update_time" field.

func UpdateTimeLTE

func UpdateTimeLTE(v time.Time) predicate.Customer

UpdateTimeLTE applies the LTE predicate on the "update_time" field.

func UpdateTimeNEQ

func UpdateTimeNEQ(v time.Time) predicate.Customer

UpdateTimeNEQ applies the NEQ predicate on the "update_time" field.

func UpdateTimeNotIn

func UpdateTimeNotIn(vs ...time.Time) predicate.Customer

UpdateTimeNotIn applies the NotIn predicate on the "update_time" field.

func Username

func Username(v string) predicate.Customer

Username applies equality check predicate on the "username" field. It's identical to UsernameEQ.

func UsernameContains

func UsernameContains(v string) predicate.Customer

UsernameContains applies the Contains predicate on the "username" field.

func UsernameContainsFold

func UsernameContainsFold(v string) predicate.Customer

UsernameContainsFold applies the ContainsFold predicate on the "username" field.

func UsernameEQ

func UsernameEQ(v string) predicate.Customer

UsernameEQ applies the EQ predicate on the "username" field.

func UsernameEqualFold

func UsernameEqualFold(v string) predicate.Customer

UsernameEqualFold applies the EqualFold predicate on the "username" field.

func UsernameGT

func UsernameGT(v string) predicate.Customer

UsernameGT applies the GT predicate on the "username" field.

func UsernameGTE

func UsernameGTE(v string) predicate.Customer

UsernameGTE applies the GTE predicate on the "username" field.

func UsernameHasPrefix

func UsernameHasPrefix(v string) predicate.Customer

UsernameHasPrefix applies the HasPrefix predicate on the "username" field.

func UsernameHasSuffix

func UsernameHasSuffix(v string) predicate.Customer

UsernameHasSuffix applies the HasSuffix predicate on the "username" field.

func UsernameIn

func UsernameIn(vs ...string) predicate.Customer

UsernameIn applies the In predicate on the "username" field.

func UsernameLT

func UsernameLT(v string) predicate.Customer

UsernameLT applies the LT predicate on the "username" field.

func UsernameLTE

func UsernameLTE(v string) predicate.Customer

UsernameLTE applies the LTE predicate on the "username" field.

func UsernameNEQ

func UsernameNEQ(v string) predicate.Customer

UsernameNEQ applies the NEQ predicate on the "username" field.

func UsernameNotIn

func UsernameNotIn(vs ...string) predicate.Customer

UsernameNotIn applies the NotIn predicate on the "username" field.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

Types

This section is empty.

Jump to