partner

package
v0.0.0-...-2dc66f2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 18, 2023 License: MIT Imports: 4 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the partner type in the database.
	Label = "partner"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldCreateTime holds the string denoting the create_time field in the database.
	FieldCreateTime = "create_time"
	// FieldUpdateTime holds the string denoting the update_time field in the database.
	FieldUpdateTime = "update_time"
	// FieldAPIKey holds the string denoting the api_key field in the database.
	FieldAPIKey = "api_key"
	// FieldSecretKey holds the string denoting the secret_key field in the database.
	FieldSecretKey = "secret_key"
	// FieldPublicKey holds the string denoting the public_key field in the database.
	FieldPublicKey = "public_key"
	// FieldPrivateKey holds the string denoting the private_key field in the database.
	FieldPrivateKey = "private_key"
	// FieldName holds the string denoting the name field in the database.
	FieldName = "name"
	// FieldIsActive holds the string denoting the is_active field in the database.
	FieldIsActive = "is_active"
	// Table holds the table name of the partner in the database.
	Table = "partners"
)

Variables

var (
	// DefaultCreateTime holds the default value on creation for the "create_time" field.
	DefaultCreateTime func() time.Time
	// DefaultUpdateTime holds the default value on creation for the "update_time" field.
	DefaultUpdateTime func() time.Time
	// UpdateDefaultUpdateTime holds the default value on update for the "update_time" field.
	UpdateDefaultUpdateTime func() time.Time
	// DefaultName holds the default value on creation for the "name" field.
	DefaultName string
	// NameValidator is a validator for the "name" field. It is called by the builders before save.
	NameValidator func(string) error
	// DefaultIsActive holds the default value on creation for the "is_active" field.
	DefaultIsActive bool
	// DefaultID holds the default value on creation for the "id" field.
	DefaultID func() uuid.UUID
)

Columns holds all SQL columns for partner fields.

Functions

func APIKey

func APIKey(v string) predicate.Partner

APIKey applies equality check predicate on the "api_key" field. It's identical to APIKeyEQ.

func APIKeyContains

func APIKeyContains(v string) predicate.Partner

APIKeyContains applies the Contains predicate on the "api_key" field.

func APIKeyContainsFold

func APIKeyContainsFold(v string) predicate.Partner

APIKeyContainsFold applies the ContainsFold predicate on the "api_key" field.

func APIKeyEQ

func APIKeyEQ(v string) predicate.Partner

APIKeyEQ applies the EQ predicate on the "api_key" field.

func APIKeyEqualFold

func APIKeyEqualFold(v string) predicate.Partner

APIKeyEqualFold applies the EqualFold predicate on the "api_key" field.

func APIKeyGT

func APIKeyGT(v string) predicate.Partner

APIKeyGT applies the GT predicate on the "api_key" field.

func APIKeyGTE

func APIKeyGTE(v string) predicate.Partner

APIKeyGTE applies the GTE predicate on the "api_key" field.

func APIKeyHasPrefix

func APIKeyHasPrefix(v string) predicate.Partner

APIKeyHasPrefix applies the HasPrefix predicate on the "api_key" field.

func APIKeyHasSuffix

func APIKeyHasSuffix(v string) predicate.Partner

APIKeyHasSuffix applies the HasSuffix predicate on the "api_key" field.

func APIKeyIn

func APIKeyIn(vs ...string) predicate.Partner

APIKeyIn applies the In predicate on the "api_key" field.

func APIKeyLT

func APIKeyLT(v string) predicate.Partner

APIKeyLT applies the LT predicate on the "api_key" field.

func APIKeyLTE

func APIKeyLTE(v string) predicate.Partner

APIKeyLTE applies the LTE predicate on the "api_key" field.

func APIKeyNEQ

func APIKeyNEQ(v string) predicate.Partner

APIKeyNEQ applies the NEQ predicate on the "api_key" field.

func APIKeyNotIn

func APIKeyNotIn(vs ...string) predicate.Partner

APIKeyNotIn applies the NotIn predicate on the "api_key" field.

func And

func And(predicates ...predicate.Partner) predicate.Partner

And groups predicates with the AND operator between them.

func CreateTime

func CreateTime(v time.Time) predicate.Partner

CreateTime applies equality check predicate on the "create_time" field. It's identical to CreateTimeEQ.

func CreateTimeEQ

func CreateTimeEQ(v time.Time) predicate.Partner

CreateTimeEQ applies the EQ predicate on the "create_time" field.

func CreateTimeGT

func CreateTimeGT(v time.Time) predicate.Partner

CreateTimeGT applies the GT predicate on the "create_time" field.

func CreateTimeGTE

func CreateTimeGTE(v time.Time) predicate.Partner

CreateTimeGTE applies the GTE predicate on the "create_time" field.

func CreateTimeIn

func CreateTimeIn(vs ...time.Time) predicate.Partner

CreateTimeIn applies the In predicate on the "create_time" field.

func CreateTimeLT

func CreateTimeLT(v time.Time) predicate.Partner

CreateTimeLT applies the LT predicate on the "create_time" field.

func CreateTimeLTE

func CreateTimeLTE(v time.Time) predicate.Partner

CreateTimeLTE applies the LTE predicate on the "create_time" field.

func CreateTimeNEQ

func CreateTimeNEQ(v time.Time) predicate.Partner

CreateTimeNEQ applies the NEQ predicate on the "create_time" field.

func CreateTimeNotIn

func CreateTimeNotIn(vs ...time.Time) predicate.Partner

CreateTimeNotIn applies the NotIn predicate on the "create_time" field.

func ID

func ID(id uuid.UUID) predicate.Partner

ID filters vertices based on their ID field.

func IDEQ

func IDEQ(id uuid.UUID) predicate.Partner

IDEQ applies the EQ predicate on the ID field.

func IDGT

func IDGT(id uuid.UUID) predicate.Partner

IDGT applies the GT predicate on the ID field.

func IDGTE

func IDGTE(id uuid.UUID) predicate.Partner

IDGTE applies the GTE predicate on the ID field.

func IDIn

func IDIn(ids ...uuid.UUID) predicate.Partner

IDIn applies the In predicate on the ID field.

func IDLT

func IDLT(id uuid.UUID) predicate.Partner

IDLT applies the LT predicate on the ID field.

func IDLTE

func IDLTE(id uuid.UUID) predicate.Partner

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

func IDNEQ(id uuid.UUID) predicate.Partner

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...uuid.UUID) predicate.Partner

IDNotIn applies the NotIn predicate on the ID field.

func IsActive

func IsActive(v bool) predicate.Partner

IsActive applies equality check predicate on the "is_active" field. It's identical to IsActiveEQ.

func IsActiveEQ

func IsActiveEQ(v bool) predicate.Partner

IsActiveEQ applies the EQ predicate on the "is_active" field.

func IsActiveIsNil

func IsActiveIsNil() predicate.Partner

IsActiveIsNil applies the IsNil predicate on the "is_active" field.

func IsActiveNEQ

func IsActiveNEQ(v bool) predicate.Partner

IsActiveNEQ applies the NEQ predicate on the "is_active" field.

func IsActiveNotNil

func IsActiveNotNil() predicate.Partner

IsActiveNotNil applies the NotNil predicate on the "is_active" field.

func Name

func Name(v string) predicate.Partner

Name applies equality check predicate on the "name" field. It's identical to NameEQ.

func NameContains

func NameContains(v string) predicate.Partner

NameContains applies the Contains predicate on the "name" field.

func NameContainsFold

func NameContainsFold(v string) predicate.Partner

NameContainsFold applies the ContainsFold predicate on the "name" field.

func NameEQ

func NameEQ(v string) predicate.Partner

NameEQ applies the EQ predicate on the "name" field.

func NameEqualFold

func NameEqualFold(v string) predicate.Partner

NameEqualFold applies the EqualFold predicate on the "name" field.

func NameGT

func NameGT(v string) predicate.Partner

NameGT applies the GT predicate on the "name" field.

func NameGTE

func NameGTE(v string) predicate.Partner

NameGTE applies the GTE predicate on the "name" field.

func NameHasPrefix

func NameHasPrefix(v string) predicate.Partner

NameHasPrefix applies the HasPrefix predicate on the "name" field.

func NameHasSuffix

func NameHasSuffix(v string) predicate.Partner

NameHasSuffix applies the HasSuffix predicate on the "name" field.

func NameIn

func NameIn(vs ...string) predicate.Partner

NameIn applies the In predicate on the "name" field.

func NameIsNil

func NameIsNil() predicate.Partner

NameIsNil applies the IsNil predicate on the "name" field.

func NameLT

func NameLT(v string) predicate.Partner

NameLT applies the LT predicate on the "name" field.

func NameLTE

func NameLTE(v string) predicate.Partner

NameLTE applies the LTE predicate on the "name" field.

func NameNEQ

func NameNEQ(v string) predicate.Partner

NameNEQ applies the NEQ predicate on the "name" field.

func NameNotIn

func NameNotIn(vs ...string) predicate.Partner

NameNotIn applies the NotIn predicate on the "name" field.

func NameNotNil

func NameNotNil() predicate.Partner

NameNotNil applies the NotNil predicate on the "name" field.

func Not

Not applies the not operator on the given predicate.

func Or

func Or(predicates ...predicate.Partner) predicate.Partner

Or groups predicates with the OR operator between them.

func PrivateKey

func PrivateKey(v string) predicate.Partner

PrivateKey applies equality check predicate on the "private_key" field. It's identical to PrivateKeyEQ.

func PrivateKeyContains

func PrivateKeyContains(v string) predicate.Partner

PrivateKeyContains applies the Contains predicate on the "private_key" field.

func PrivateKeyContainsFold

func PrivateKeyContainsFold(v string) predicate.Partner

PrivateKeyContainsFold applies the ContainsFold predicate on the "private_key" field.

func PrivateKeyEQ

func PrivateKeyEQ(v string) predicate.Partner

PrivateKeyEQ applies the EQ predicate on the "private_key" field.

func PrivateKeyEqualFold

func PrivateKeyEqualFold(v string) predicate.Partner

PrivateKeyEqualFold applies the EqualFold predicate on the "private_key" field.

func PrivateKeyGT

func PrivateKeyGT(v string) predicate.Partner

PrivateKeyGT applies the GT predicate on the "private_key" field.

func PrivateKeyGTE

func PrivateKeyGTE(v string) predicate.Partner

PrivateKeyGTE applies the GTE predicate on the "private_key" field.

func PrivateKeyHasPrefix

func PrivateKeyHasPrefix(v string) predicate.Partner

PrivateKeyHasPrefix applies the HasPrefix predicate on the "private_key" field.

func PrivateKeyHasSuffix

func PrivateKeyHasSuffix(v string) predicate.Partner

PrivateKeyHasSuffix applies the HasSuffix predicate on the "private_key" field.

func PrivateKeyIn

func PrivateKeyIn(vs ...string) predicate.Partner

PrivateKeyIn applies the In predicate on the "private_key" field.

func PrivateKeyLT

func PrivateKeyLT(v string) predicate.Partner

PrivateKeyLT applies the LT predicate on the "private_key" field.

func PrivateKeyLTE

func PrivateKeyLTE(v string) predicate.Partner

PrivateKeyLTE applies the LTE predicate on the "private_key" field.

func PrivateKeyNEQ

func PrivateKeyNEQ(v string) predicate.Partner

PrivateKeyNEQ applies the NEQ predicate on the "private_key" field.

func PrivateKeyNotIn

func PrivateKeyNotIn(vs ...string) predicate.Partner

PrivateKeyNotIn applies the NotIn predicate on the "private_key" field.

func PublicKey

func PublicKey(v string) predicate.Partner

PublicKey applies equality check predicate on the "public_key" field. It's identical to PublicKeyEQ.

func PublicKeyContains

func PublicKeyContains(v string) predicate.Partner

PublicKeyContains applies the Contains predicate on the "public_key" field.

func PublicKeyContainsFold

func PublicKeyContainsFold(v string) predicate.Partner

PublicKeyContainsFold applies the ContainsFold predicate on the "public_key" field.

func PublicKeyEQ

func PublicKeyEQ(v string) predicate.Partner

PublicKeyEQ applies the EQ predicate on the "public_key" field.

func PublicKeyEqualFold

func PublicKeyEqualFold(v string) predicate.Partner

PublicKeyEqualFold applies the EqualFold predicate on the "public_key" field.

func PublicKeyGT

func PublicKeyGT(v string) predicate.Partner

PublicKeyGT applies the GT predicate on the "public_key" field.

func PublicKeyGTE

func PublicKeyGTE(v string) predicate.Partner

PublicKeyGTE applies the GTE predicate on the "public_key" field.

func PublicKeyHasPrefix

func PublicKeyHasPrefix(v string) predicate.Partner

PublicKeyHasPrefix applies the HasPrefix predicate on the "public_key" field.

func PublicKeyHasSuffix

func PublicKeyHasSuffix(v string) predicate.Partner

PublicKeyHasSuffix applies the HasSuffix predicate on the "public_key" field.

func PublicKeyIn

func PublicKeyIn(vs ...string) predicate.Partner

PublicKeyIn applies the In predicate on the "public_key" field.

func PublicKeyLT

func PublicKeyLT(v string) predicate.Partner

PublicKeyLT applies the LT predicate on the "public_key" field.

func PublicKeyLTE

func PublicKeyLTE(v string) predicate.Partner

PublicKeyLTE applies the LTE predicate on the "public_key" field.

func PublicKeyNEQ

func PublicKeyNEQ(v string) predicate.Partner

PublicKeyNEQ applies the NEQ predicate on the "public_key" field.

func PublicKeyNotIn

func PublicKeyNotIn(vs ...string) predicate.Partner

PublicKeyNotIn applies the NotIn predicate on the "public_key" field.

func SecretKey

func SecretKey(v string) predicate.Partner

SecretKey applies equality check predicate on the "secret_key" field. It's identical to SecretKeyEQ.

func SecretKeyContains

func SecretKeyContains(v string) predicate.Partner

SecretKeyContains applies the Contains predicate on the "secret_key" field.

func SecretKeyContainsFold

func SecretKeyContainsFold(v string) predicate.Partner

SecretKeyContainsFold applies the ContainsFold predicate on the "secret_key" field.

func SecretKeyEQ

func SecretKeyEQ(v string) predicate.Partner

SecretKeyEQ applies the EQ predicate on the "secret_key" field.

func SecretKeyEqualFold

func SecretKeyEqualFold(v string) predicate.Partner

SecretKeyEqualFold applies the EqualFold predicate on the "secret_key" field.

func SecretKeyGT

func SecretKeyGT(v string) predicate.Partner

SecretKeyGT applies the GT predicate on the "secret_key" field.

func SecretKeyGTE

func SecretKeyGTE(v string) predicate.Partner

SecretKeyGTE applies the GTE predicate on the "secret_key" field.

func SecretKeyHasPrefix

func SecretKeyHasPrefix(v string) predicate.Partner

SecretKeyHasPrefix applies the HasPrefix predicate on the "secret_key" field.

func SecretKeyHasSuffix

func SecretKeyHasSuffix(v string) predicate.Partner

SecretKeyHasSuffix applies the HasSuffix predicate on the "secret_key" field.

func SecretKeyIn

func SecretKeyIn(vs ...string) predicate.Partner

SecretKeyIn applies the In predicate on the "secret_key" field.

func SecretKeyLT

func SecretKeyLT(v string) predicate.Partner

SecretKeyLT applies the LT predicate on the "secret_key" field.

func SecretKeyLTE

func SecretKeyLTE(v string) predicate.Partner

SecretKeyLTE applies the LTE predicate on the "secret_key" field.

func SecretKeyNEQ

func SecretKeyNEQ(v string) predicate.Partner

SecretKeyNEQ applies the NEQ predicate on the "secret_key" field.

func SecretKeyNotIn

func SecretKeyNotIn(vs ...string) predicate.Partner

SecretKeyNotIn applies the NotIn predicate on the "secret_key" field.

func UpdateTime

func UpdateTime(v time.Time) predicate.Partner

UpdateTime applies equality check predicate on the "update_time" field. It's identical to UpdateTimeEQ.

func UpdateTimeEQ

func UpdateTimeEQ(v time.Time) predicate.Partner

UpdateTimeEQ applies the EQ predicate on the "update_time" field.

func UpdateTimeGT

func UpdateTimeGT(v time.Time) predicate.Partner

UpdateTimeGT applies the GT predicate on the "update_time" field.

func UpdateTimeGTE

func UpdateTimeGTE(v time.Time) predicate.Partner

UpdateTimeGTE applies the GTE predicate on the "update_time" field.

func UpdateTimeIn

func UpdateTimeIn(vs ...time.Time) predicate.Partner

UpdateTimeIn applies the In predicate on the "update_time" field.

func UpdateTimeLT

func UpdateTimeLT(v time.Time) predicate.Partner

UpdateTimeLT applies the LT predicate on the "update_time" field.

func UpdateTimeLTE

func UpdateTimeLTE(v time.Time) predicate.Partner

UpdateTimeLTE applies the LTE predicate on the "update_time" field.

func UpdateTimeNEQ

func UpdateTimeNEQ(v time.Time) predicate.Partner

UpdateTimeNEQ applies the NEQ predicate on the "update_time" field.

func UpdateTimeNotIn

func UpdateTimeNotIn(vs ...time.Time) predicate.Partner

UpdateTimeNotIn applies the NotIn predicate on the "update_time" field.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

Types

This section is empty.

Jump to