Documentation
¶
Index ¶
- Constants
- Variables
- func AccountNumber(v string) predicate.Contact
- func AccountNumberContains(v string) predicate.Contact
- func AccountNumberContainsFold(v string) predicate.Contact
- func AccountNumberEQ(v string) predicate.Contact
- func AccountNumberEqualFold(v string) predicate.Contact
- func AccountNumberGT(v string) predicate.Contact
- func AccountNumberGTE(v string) predicate.Contact
- func AccountNumberHasPrefix(v string) predicate.Contact
- func AccountNumberHasSuffix(v string) predicate.Contact
- func AccountNumberIn(vs ...string) predicate.Contact
- func AccountNumberLT(v string) predicate.Contact
- func AccountNumberLTE(v string) predicate.Contact
- func AccountNumberNEQ(v string) predicate.Contact
- func AccountNumberNotIn(vs ...string) predicate.Contact
- func And(predicates ...predicate.Contact) predicate.Contact
- func BankName(v string) predicate.Contact
- func BankNameContains(v string) predicate.Contact
- func BankNameContainsFold(v string) predicate.Contact
- func BankNameEQ(v string) predicate.Contact
- func BankNameEqualFold(v string) predicate.Contact
- func BankNameGT(v string) predicate.Contact
- func BankNameGTE(v string) predicate.Contact
- func BankNameHasPrefix(v string) predicate.Contact
- func BankNameHasSuffix(v string) predicate.Contact
- func BankNameIn(vs ...string) predicate.Contact
- func BankNameLT(v string) predicate.Contact
- func BankNameLTE(v string) predicate.Contact
- func BankNameNEQ(v string) predicate.Contact
- func BankNameNotIn(vs ...string) predicate.Contact
- func CreateTime(v time.Time) predicate.Contact
- func CreateTimeEQ(v time.Time) predicate.Contact
- func CreateTimeGT(v time.Time) predicate.Contact
- func CreateTimeGTE(v time.Time) predicate.Contact
- func CreateTimeIn(vs ...time.Time) predicate.Contact
- func CreateTimeLT(v time.Time) predicate.Contact
- func CreateTimeLTE(v time.Time) predicate.Contact
- func CreateTimeNEQ(v time.Time) predicate.Contact
- func CreateTimeNotIn(vs ...time.Time) predicate.Contact
- func HasOwner() predicate.Contact
- func HasOwnerWith(preds ...predicate.Customer) predicate.Contact
- func ID(id uuid.UUID) predicate.Contact
- func IDEQ(id uuid.UUID) predicate.Contact
- func IDGT(id uuid.UUID) predicate.Contact
- func IDGTE(id uuid.UUID) predicate.Contact
- func IDIn(ids ...uuid.UUID) predicate.Contact
- func IDLT(id uuid.UUID) predicate.Contact
- func IDLTE(id uuid.UUID) predicate.Contact
- func IDNEQ(id uuid.UUID) predicate.Contact
- func IDNotIn(ids ...uuid.UUID) predicate.Contact
- func Not(p predicate.Contact) predicate.Contact
- func Or(predicates ...predicate.Contact) predicate.Contact
- func OwnerID(v uuid.UUID) predicate.Contact
- func OwnerIDEQ(v uuid.UUID) predicate.Contact
- func OwnerIDIn(vs ...uuid.UUID) predicate.Contact
- func OwnerIDNEQ(v uuid.UUID) predicate.Contact
- func OwnerIDNotIn(vs ...uuid.UUID) predicate.Contact
- func SuggestName(v string) predicate.Contact
- func SuggestNameContains(v string) predicate.Contact
- func SuggestNameContainsFold(v string) predicate.Contact
- func SuggestNameEQ(v string) predicate.Contact
- func SuggestNameEqualFold(v string) predicate.Contact
- func SuggestNameGT(v string) predicate.Contact
- func SuggestNameGTE(v string) predicate.Contact
- func SuggestNameHasPrefix(v string) predicate.Contact
- func SuggestNameHasSuffix(v string) predicate.Contact
- func SuggestNameIn(vs ...string) predicate.Contact
- func SuggestNameLT(v string) predicate.Contact
- func SuggestNameLTE(v string) predicate.Contact
- func SuggestNameNEQ(v string) predicate.Contact
- func SuggestNameNotIn(vs ...string) predicate.Contact
- func UpdateTime(v time.Time) predicate.Contact
- func UpdateTimeEQ(v time.Time) predicate.Contact
- func UpdateTimeGT(v time.Time) predicate.Contact
- func UpdateTimeGTE(v time.Time) predicate.Contact
- func UpdateTimeIn(vs ...time.Time) predicate.Contact
- func UpdateTimeLT(v time.Time) predicate.Contact
- func UpdateTimeLTE(v time.Time) predicate.Contact
- func UpdateTimeNEQ(v time.Time) predicate.Contact
- func UpdateTimeNotIn(vs ...time.Time) predicate.Contact
- func ValidColumn(column string) bool
Constants ¶
const ( // Label holds the string label denoting the contact type in the database. Label = "contact" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldCreateTime holds the string denoting the create_time field in the database. FieldCreateTime = "create_time" // FieldUpdateTime holds the string denoting the update_time field in the database. FieldUpdateTime = "update_time" // FieldOwnerID holds the string denoting the owner_id field in the database. FieldOwnerID = "owner_id" // FieldAccountNumber holds the string denoting the account_number field in the database. FieldAccountNumber = "account_number" // FieldSuggestName holds the string denoting the suggest_name field in the database. FieldSuggestName = "suggest_name" // FieldBankName holds the string denoting the bank_name field in the database. FieldBankName = "bank_name" // EdgeOwner holds the string denoting the owner edge name in mutations. EdgeOwner = "owner" // Table holds the table name of the contact in the database. Table = "contacts" // OwnerTable is the table that holds the owner relation/edge. OwnerTable = "contacts" // OwnerInverseTable is the table name for the Customer entity. // It exists in this package in order to avoid circular dependency with the "customer" package. OwnerInverseTable = "customers" // OwnerColumn is the table column denoting the owner relation/edge. OwnerColumn = "owner_id" )
Variables ¶
var ( // DefaultCreateTime holds the default value on creation for the "create_time" field. DefaultCreateTime func() time.Time // DefaultUpdateTime holds the default value on creation for the "update_time" field. DefaultUpdateTime func() time.Time // UpdateDefaultUpdateTime holds the default value on update for the "update_time" field. UpdateDefaultUpdateTime func() time.Time // AccountNumberValidator is a validator for the "account_number" field. It is called by the builders before save. AccountNumberValidator func(string) error // SuggestNameValidator is a validator for the "suggest_name" field. It is called by the builders before save. SuggestNameValidator func(string) error // DefaultID holds the default value on creation for the "id" field. DefaultID func() uuid.UUID )
var Columns = []string{ FieldID, FieldCreateTime, FieldUpdateTime, FieldOwnerID, FieldAccountNumber, FieldSuggestName, FieldBankName, }
Columns holds all SQL columns for contact fields.
Functions ¶
func AccountNumber ¶
AccountNumber applies equality check predicate on the "account_number" field. It's identical to AccountNumberEQ.
func AccountNumberContains ¶
AccountNumberContains applies the Contains predicate on the "account_number" field.
func AccountNumberContainsFold ¶
AccountNumberContainsFold applies the ContainsFold predicate on the "account_number" field.
func AccountNumberEQ ¶
AccountNumberEQ applies the EQ predicate on the "account_number" field.
func AccountNumberEqualFold ¶
AccountNumberEqualFold applies the EqualFold predicate on the "account_number" field.
func AccountNumberGT ¶
AccountNumberGT applies the GT predicate on the "account_number" field.
func AccountNumberGTE ¶
AccountNumberGTE applies the GTE predicate on the "account_number" field.
func AccountNumberHasPrefix ¶
AccountNumberHasPrefix applies the HasPrefix predicate on the "account_number" field.
func AccountNumberHasSuffix ¶
AccountNumberHasSuffix applies the HasSuffix predicate on the "account_number" field.
func AccountNumberIn ¶
AccountNumberIn applies the In predicate on the "account_number" field.
func AccountNumberLT ¶
AccountNumberLT applies the LT predicate on the "account_number" field.
func AccountNumberLTE ¶
AccountNumberLTE applies the LTE predicate on the "account_number" field.
func AccountNumberNEQ ¶
AccountNumberNEQ applies the NEQ predicate on the "account_number" field.
func AccountNumberNotIn ¶
AccountNumberNotIn applies the NotIn predicate on the "account_number" field.
func BankName ¶
BankName applies equality check predicate on the "bank_name" field. It's identical to BankNameEQ.
func BankNameContains ¶
BankNameContains applies the Contains predicate on the "bank_name" field.
func BankNameContainsFold ¶
BankNameContainsFold applies the ContainsFold predicate on the "bank_name" field.
func BankNameEQ ¶
BankNameEQ applies the EQ predicate on the "bank_name" field.
func BankNameEqualFold ¶
BankNameEqualFold applies the EqualFold predicate on the "bank_name" field.
func BankNameGT ¶
BankNameGT applies the GT predicate on the "bank_name" field.
func BankNameGTE ¶
BankNameGTE applies the GTE predicate on the "bank_name" field.
func BankNameHasPrefix ¶
BankNameHasPrefix applies the HasPrefix predicate on the "bank_name" field.
func BankNameHasSuffix ¶
BankNameHasSuffix applies the HasSuffix predicate on the "bank_name" field.
func BankNameIn ¶
BankNameIn applies the In predicate on the "bank_name" field.
func BankNameLT ¶
BankNameLT applies the LT predicate on the "bank_name" field.
func BankNameLTE ¶
BankNameLTE applies the LTE predicate on the "bank_name" field.
func BankNameNEQ ¶
BankNameNEQ applies the NEQ predicate on the "bank_name" field.
func BankNameNotIn ¶
BankNameNotIn applies the NotIn predicate on the "bank_name" field.
func CreateTime ¶
CreateTime applies equality check predicate on the "create_time" field. It's identical to CreateTimeEQ.
func CreateTimeEQ ¶
CreateTimeEQ applies the EQ predicate on the "create_time" field.
func CreateTimeGT ¶
CreateTimeGT applies the GT predicate on the "create_time" field.
func CreateTimeGTE ¶
CreateTimeGTE applies the GTE predicate on the "create_time" field.
func CreateTimeIn ¶
CreateTimeIn applies the In predicate on the "create_time" field.
func CreateTimeLT ¶
CreateTimeLT applies the LT predicate on the "create_time" field.
func CreateTimeLTE ¶
CreateTimeLTE applies the LTE predicate on the "create_time" field.
func CreateTimeNEQ ¶
CreateTimeNEQ applies the NEQ predicate on the "create_time" field.
func CreateTimeNotIn ¶
CreateTimeNotIn applies the NotIn predicate on the "create_time" field.
func HasOwnerWith ¶
HasOwnerWith applies the HasEdge predicate on the "owner" edge with a given conditions (other predicates).
func OwnerID ¶
OwnerID applies equality check predicate on the "owner_id" field. It's identical to OwnerIDEQ.
func OwnerIDNEQ ¶
OwnerIDNEQ applies the NEQ predicate on the "owner_id" field.
func OwnerIDNotIn ¶
OwnerIDNotIn applies the NotIn predicate on the "owner_id" field.
func SuggestName ¶
SuggestName applies equality check predicate on the "suggest_name" field. It's identical to SuggestNameEQ.
func SuggestNameContains ¶
SuggestNameContains applies the Contains predicate on the "suggest_name" field.
func SuggestNameContainsFold ¶
SuggestNameContainsFold applies the ContainsFold predicate on the "suggest_name" field.
func SuggestNameEQ ¶
SuggestNameEQ applies the EQ predicate on the "suggest_name" field.
func SuggestNameEqualFold ¶
SuggestNameEqualFold applies the EqualFold predicate on the "suggest_name" field.
func SuggestNameGT ¶
SuggestNameGT applies the GT predicate on the "suggest_name" field.
func SuggestNameGTE ¶
SuggestNameGTE applies the GTE predicate on the "suggest_name" field.
func SuggestNameHasPrefix ¶
SuggestNameHasPrefix applies the HasPrefix predicate on the "suggest_name" field.
func SuggestNameHasSuffix ¶
SuggestNameHasSuffix applies the HasSuffix predicate on the "suggest_name" field.
func SuggestNameIn ¶
SuggestNameIn applies the In predicate on the "suggest_name" field.
func SuggestNameLT ¶
SuggestNameLT applies the LT predicate on the "suggest_name" field.
func SuggestNameLTE ¶
SuggestNameLTE applies the LTE predicate on the "suggest_name" field.
func SuggestNameNEQ ¶
SuggestNameNEQ applies the NEQ predicate on the "suggest_name" field.
func SuggestNameNotIn ¶
SuggestNameNotIn applies the NotIn predicate on the "suggest_name" field.
func UpdateTime ¶
UpdateTime applies equality check predicate on the "update_time" field. It's identical to UpdateTimeEQ.
func UpdateTimeEQ ¶
UpdateTimeEQ applies the EQ predicate on the "update_time" field.
func UpdateTimeGT ¶
UpdateTimeGT applies the GT predicate on the "update_time" field.
func UpdateTimeGTE ¶
UpdateTimeGTE applies the GTE predicate on the "update_time" field.
func UpdateTimeIn ¶
UpdateTimeIn applies the In predicate on the "update_time" field.
func UpdateTimeLT ¶
UpdateTimeLT applies the LT predicate on the "update_time" field.
func UpdateTimeLTE ¶
UpdateTimeLTE applies the LTE predicate on the "update_time" field.
func UpdateTimeNEQ ¶
UpdateTimeNEQ applies the NEQ predicate on the "update_time" field.
func UpdateTimeNotIn ¶
UpdateTimeNotIn applies the NotIn predicate on the "update_time" field.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
Types ¶
This section is empty.