Documentation
¶
Index ¶
- Constants
- Variables
- func And(predicates ...predicate.Customer) predicate.Customer
- func CreateTime(v time.Time) predicate.Customer
- func CreateTimeEQ(v time.Time) predicate.Customer
- func CreateTimeGT(v time.Time) predicate.Customer
- func CreateTimeGTE(v time.Time) predicate.Customer
- func CreateTimeIn(vs ...time.Time) predicate.Customer
- func CreateTimeLT(v time.Time) predicate.Customer
- func CreateTimeLTE(v time.Time) predicate.Customer
- func CreateTimeNEQ(v time.Time) predicate.Customer
- func CreateTimeNotIn(vs ...time.Time) predicate.Customer
- func Email(v string) predicate.Customer
- func EmailContains(v string) predicate.Customer
- func EmailContainsFold(v string) predicate.Customer
- func EmailEQ(v string) predicate.Customer
- func EmailEqualFold(v string) predicate.Customer
- func EmailGT(v string) predicate.Customer
- func EmailGTE(v string) predicate.Customer
- func EmailHasPrefix(v string) predicate.Customer
- func EmailHasSuffix(v string) predicate.Customer
- func EmailIn(vs ...string) predicate.Customer
- func EmailLT(v string) predicate.Customer
- func EmailLTE(v string) predicate.Customer
- func EmailNEQ(v string) predicate.Customer
- func EmailNotIn(vs ...string) predicate.Customer
- func FirstName(v string) predicate.Customer
- func FirstNameContains(v string) predicate.Customer
- func FirstNameContainsFold(v string) predicate.Customer
- func FirstNameEQ(v string) predicate.Customer
- func FirstNameEqualFold(v string) predicate.Customer
- func FirstNameGT(v string) predicate.Customer
- func FirstNameGTE(v string) predicate.Customer
- func FirstNameHasPrefix(v string) predicate.Customer
- func FirstNameHasSuffix(v string) predicate.Customer
- func FirstNameIn(vs ...string) predicate.Customer
- func FirstNameIsNil() predicate.Customer
- func FirstNameLT(v string) predicate.Customer
- func FirstNameLTE(v string) predicate.Customer
- func FirstNameNEQ(v string) predicate.Customer
- func FirstNameNotIn(vs ...string) predicate.Customer
- func FirstNameNotNil() predicate.Customer
- func HasBankAccounts() predicate.Customer
- func HasBankAccountsWith(preds ...predicate.BankAccount) predicate.Customer
- func HasContacts() predicate.Customer
- func HasContactsWith(preds ...predicate.Contact) predicate.Customer
- func ID(id uuid.UUID) predicate.Customer
- func IDEQ(id uuid.UUID) predicate.Customer
- func IDGT(id uuid.UUID) predicate.Customer
- func IDGTE(id uuid.UUID) predicate.Customer
- func IDIn(ids ...uuid.UUID) predicate.Customer
- func IDLT(id uuid.UUID) predicate.Customer
- func IDLTE(id uuid.UUID) predicate.Customer
- func IDNEQ(id uuid.UUID) predicate.Customer
- func IDNotIn(ids ...uuid.UUID) predicate.Customer
- func IsActive(v bool) predicate.Customer
- func IsActiveEQ(v bool) predicate.Customer
- func IsActiveIsNil() predicate.Customer
- func IsActiveNEQ(v bool) predicate.Customer
- func IsActiveNotNil() predicate.Customer
- func JwtTokenKey(v string) predicate.Customer
- func JwtTokenKeyContains(v string) predicate.Customer
- func JwtTokenKeyContainsFold(v string) predicate.Customer
- func JwtTokenKeyEQ(v string) predicate.Customer
- func JwtTokenKeyEqualFold(v string) predicate.Customer
- func JwtTokenKeyGT(v string) predicate.Customer
- func JwtTokenKeyGTE(v string) predicate.Customer
- func JwtTokenKeyHasPrefix(v string) predicate.Customer
- func JwtTokenKeyHasSuffix(v string) predicate.Customer
- func JwtTokenKeyIn(vs ...string) predicate.Customer
- func JwtTokenKeyIsNil() predicate.Customer
- func JwtTokenKeyLT(v string) predicate.Customer
- func JwtTokenKeyLTE(v string) predicate.Customer
- func JwtTokenKeyNEQ(v string) predicate.Customer
- func JwtTokenKeyNotIn(vs ...string) predicate.Customer
- func JwtTokenKeyNotNil() predicate.Customer
- func LastName(v string) predicate.Customer
- func LastNameContains(v string) predicate.Customer
- func LastNameContainsFold(v string) predicate.Customer
- func LastNameEQ(v string) predicate.Customer
- func LastNameEqualFold(v string) predicate.Customer
- func LastNameGT(v string) predicate.Customer
- func LastNameGTE(v string) predicate.Customer
- func LastNameHasPrefix(v string) predicate.Customer
- func LastNameHasSuffix(v string) predicate.Customer
- func LastNameIn(vs ...string) predicate.Customer
- func LastNameIsNil() predicate.Customer
- func LastNameLT(v string) predicate.Customer
- func LastNameLTE(v string) predicate.Customer
- func LastNameNEQ(v string) predicate.Customer
- func LastNameNotIn(vs ...string) predicate.Customer
- func LastNameNotNil() predicate.Customer
- func Not(p predicate.Customer) predicate.Customer
- func Or(predicates ...predicate.Customer) predicate.Customer
- func Password(v string) predicate.Customer
- func PasswordContains(v string) predicate.Customer
- func PasswordContainsFold(v string) predicate.Customer
- func PasswordEQ(v string) predicate.Customer
- func PasswordEqualFold(v string) predicate.Customer
- func PasswordGT(v string) predicate.Customer
- func PasswordGTE(v string) predicate.Customer
- func PasswordHasPrefix(v string) predicate.Customer
- func PasswordHasSuffix(v string) predicate.Customer
- func PasswordIn(vs ...string) predicate.Customer
- func PasswordIsNil() predicate.Customer
- func PasswordLT(v string) predicate.Customer
- func PasswordLTE(v string) predicate.Customer
- func PasswordNEQ(v string) predicate.Customer
- func PasswordNotIn(vs ...string) predicate.Customer
- func PasswordNotNil() predicate.Customer
- func PhoneNumber(v string) predicate.Customer
- func PhoneNumberContains(v string) predicate.Customer
- func PhoneNumberContainsFold(v string) predicate.Customer
- func PhoneNumberEQ(v string) predicate.Customer
- func PhoneNumberEqualFold(v string) predicate.Customer
- func PhoneNumberGT(v string) predicate.Customer
- func PhoneNumberGTE(v string) predicate.Customer
- func PhoneNumberHasPrefix(v string) predicate.Customer
- func PhoneNumberHasSuffix(v string) predicate.Customer
- func PhoneNumberIn(vs ...string) predicate.Customer
- func PhoneNumberLT(v string) predicate.Customer
- func PhoneNumberLTE(v string) predicate.Customer
- func PhoneNumberNEQ(v string) predicate.Customer
- func PhoneNumberNotIn(vs ...string) predicate.Customer
- func UpdateTime(v time.Time) predicate.Customer
- func UpdateTimeEQ(v time.Time) predicate.Customer
- func UpdateTimeGT(v time.Time) predicate.Customer
- func UpdateTimeGTE(v time.Time) predicate.Customer
- func UpdateTimeIn(vs ...time.Time) predicate.Customer
- func UpdateTimeLT(v time.Time) predicate.Customer
- func UpdateTimeLTE(v time.Time) predicate.Customer
- func UpdateTimeNEQ(v time.Time) predicate.Customer
- func UpdateTimeNotIn(vs ...time.Time) predicate.Customer
- func Username(v string) predicate.Customer
- func UsernameContains(v string) predicate.Customer
- func UsernameContainsFold(v string) predicate.Customer
- func UsernameEQ(v string) predicate.Customer
- func UsernameEqualFold(v string) predicate.Customer
- func UsernameGT(v string) predicate.Customer
- func UsernameGTE(v string) predicate.Customer
- func UsernameHasPrefix(v string) predicate.Customer
- func UsernameHasSuffix(v string) predicate.Customer
- func UsernameIn(vs ...string) predicate.Customer
- func UsernameLT(v string) predicate.Customer
- func UsernameLTE(v string) predicate.Customer
- func UsernameNEQ(v string) predicate.Customer
- func UsernameNotIn(vs ...string) predicate.Customer
- func ValidColumn(column string) bool
Constants ¶
const ( // Label holds the string label denoting the customer type in the database. Label = "customer" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldCreateTime holds the string denoting the create_time field in the database. FieldCreateTime = "create_time" // FieldUpdateTime holds the string denoting the update_time field in the database. FieldUpdateTime = "update_time" // FieldJwtTokenKey holds the string denoting the jwt_token_key field in the database. FieldJwtTokenKey = "jwt_token_key" // FieldPassword holds the string denoting the password field in the database. FieldPassword = "password" // FieldUsername holds the string denoting the username field in the database. FieldUsername = "username" // FieldFirstName holds the string denoting the first_name field in the database. FieldFirstName = "first_name" // FieldLastName holds the string denoting the last_name field in the database. FieldLastName = "last_name" // FieldPhoneNumber holds the string denoting the phone_number field in the database. FieldPhoneNumber = "phone_number" // FieldEmail holds the string denoting the email field in the database. FieldEmail = "email" // FieldIsActive holds the string denoting the is_active field in the database. FieldIsActive = "is_active" // EdgeBankAccounts holds the string denoting the bank_accounts edge name in mutations. EdgeBankAccounts = "bank_accounts" // EdgeContacts holds the string denoting the contacts edge name in mutations. EdgeContacts = "contacts" // Table holds the table name of the customer in the database. Table = "customers" // BankAccountsTable is the table that holds the bank_accounts relation/edge. BankAccountsTable = "bank_accounts" // BankAccountsInverseTable is the table name for the BankAccount entity. // It exists in this package in order to avoid circular dependency with the "bankaccount" package. BankAccountsInverseTable = "bank_accounts" // BankAccountsColumn is the table column denoting the bank_accounts relation/edge. BankAccountsColumn = "customer_id" // ContactsTable is the table that holds the contacts relation/edge. ContactsTable = "contacts" // ContactsInverseTable is the table name for the Contact entity. // It exists in this package in order to avoid circular dependency with the "contact" package. ContactsInverseTable = "contacts" // ContactsColumn is the table column denoting the contacts relation/edge. ContactsColumn = "owner_id" )
Variables ¶
var ( // DefaultCreateTime holds the default value on creation for the "create_time" field. DefaultCreateTime func() time.Time // DefaultUpdateTime holds the default value on creation for the "update_time" field. DefaultUpdateTime func() time.Time // UpdateDefaultUpdateTime holds the default value on update for the "update_time" field. UpdateDefaultUpdateTime func() time.Time // DefaultJwtTokenKey holds the default value on creation for the "jwt_token_key" field. DefaultJwtTokenKey func() string // PasswordValidator is a validator for the "password" field. It is called by the builders before save. PasswordValidator func(string) error // UsernameValidator is a validator for the "username" field. It is called by the builders before save. UsernameValidator func(string) error // DefaultFirstName holds the default value on creation for the "first_name" field. DefaultFirstName string // FirstNameValidator is a validator for the "first_name" field. It is called by the builders before save. FirstNameValidator func(string) error // DefaultLastName holds the default value on creation for the "last_name" field. DefaultLastName string // LastNameValidator is a validator for the "last_name" field. It is called by the builders before save. LastNameValidator func(string) error // PhoneNumberValidator is a validator for the "phone_number" field. It is called by the builders before save. PhoneNumberValidator func(string) error // EmailValidator is a validator for the "email" field. It is called by the builders before save. EmailValidator func(string) error // DefaultIsActive holds the default value on creation for the "is_active" field. DefaultIsActive bool // DefaultID holds the default value on creation for the "id" field. DefaultID func() uuid.UUID )
var Columns = []string{ FieldID, FieldCreateTime, FieldUpdateTime, FieldJwtTokenKey, FieldPassword, FieldUsername, FieldFirstName, FieldLastName, FieldPhoneNumber, FieldEmail, FieldIsActive, }
Columns holds all SQL columns for customer fields.
Functions ¶
func CreateTime ¶
CreateTime applies equality check predicate on the "create_time" field. It's identical to CreateTimeEQ.
func CreateTimeEQ ¶
CreateTimeEQ applies the EQ predicate on the "create_time" field.
func CreateTimeGT ¶
CreateTimeGT applies the GT predicate on the "create_time" field.
func CreateTimeGTE ¶
CreateTimeGTE applies the GTE predicate on the "create_time" field.
func CreateTimeIn ¶
CreateTimeIn applies the In predicate on the "create_time" field.
func CreateTimeLT ¶
CreateTimeLT applies the LT predicate on the "create_time" field.
func CreateTimeLTE ¶
CreateTimeLTE applies the LTE predicate on the "create_time" field.
func CreateTimeNEQ ¶
CreateTimeNEQ applies the NEQ predicate on the "create_time" field.
func CreateTimeNotIn ¶
CreateTimeNotIn applies the NotIn predicate on the "create_time" field.
func Email ¶
Email applies equality check predicate on the "email" field. It's identical to EmailEQ.
func EmailContains ¶
EmailContains applies the Contains predicate on the "email" field.
func EmailContainsFold ¶
EmailContainsFold applies the ContainsFold predicate on the "email" field.
func EmailEqualFold ¶
EmailEqualFold applies the EqualFold predicate on the "email" field.
func EmailHasPrefix ¶
EmailHasPrefix applies the HasPrefix predicate on the "email" field.
func EmailHasSuffix ¶
EmailHasSuffix applies the HasSuffix predicate on the "email" field.
func EmailNotIn ¶
EmailNotIn applies the NotIn predicate on the "email" field.
func FirstName ¶
FirstName applies equality check predicate on the "first_name" field. It's identical to FirstNameEQ.
func FirstNameContains ¶
FirstNameContains applies the Contains predicate on the "first_name" field.
func FirstNameContainsFold ¶
FirstNameContainsFold applies the ContainsFold predicate on the "first_name" field.
func FirstNameEQ ¶
FirstNameEQ applies the EQ predicate on the "first_name" field.
func FirstNameEqualFold ¶
FirstNameEqualFold applies the EqualFold predicate on the "first_name" field.
func FirstNameGT ¶
FirstNameGT applies the GT predicate on the "first_name" field.
func FirstNameGTE ¶
FirstNameGTE applies the GTE predicate on the "first_name" field.
func FirstNameHasPrefix ¶
FirstNameHasPrefix applies the HasPrefix predicate on the "first_name" field.
func FirstNameHasSuffix ¶
FirstNameHasSuffix applies the HasSuffix predicate on the "first_name" field.
func FirstNameIn ¶
FirstNameIn applies the In predicate on the "first_name" field.
func FirstNameIsNil ¶
FirstNameIsNil applies the IsNil predicate on the "first_name" field.
func FirstNameLT ¶
FirstNameLT applies the LT predicate on the "first_name" field.
func FirstNameLTE ¶
FirstNameLTE applies the LTE predicate on the "first_name" field.
func FirstNameNEQ ¶
FirstNameNEQ applies the NEQ predicate on the "first_name" field.
func FirstNameNotIn ¶
FirstNameNotIn applies the NotIn predicate on the "first_name" field.
func FirstNameNotNil ¶
FirstNameNotNil applies the NotNil predicate on the "first_name" field.
func HasBankAccounts ¶
HasBankAccounts applies the HasEdge predicate on the "bank_accounts" edge.
func HasBankAccountsWith ¶
func HasBankAccountsWith(preds ...predicate.BankAccount) predicate.Customer
HasBankAccountsWith applies the HasEdge predicate on the "bank_accounts" edge with a given conditions (other predicates).
func HasContacts ¶
HasContacts applies the HasEdge predicate on the "contacts" edge.
func HasContactsWith ¶
HasContactsWith applies the HasEdge predicate on the "contacts" edge with a given conditions (other predicates).
func IsActive ¶
IsActive applies equality check predicate on the "is_active" field. It's identical to IsActiveEQ.
func IsActiveEQ ¶
IsActiveEQ applies the EQ predicate on the "is_active" field.
func IsActiveIsNil ¶
IsActiveIsNil applies the IsNil predicate on the "is_active" field.
func IsActiveNEQ ¶
IsActiveNEQ applies the NEQ predicate on the "is_active" field.
func IsActiveNotNil ¶
IsActiveNotNil applies the NotNil predicate on the "is_active" field.
func JwtTokenKey ¶
JwtTokenKey applies equality check predicate on the "jwt_token_key" field. It's identical to JwtTokenKeyEQ.
func JwtTokenKeyContains ¶
JwtTokenKeyContains applies the Contains predicate on the "jwt_token_key" field.
func JwtTokenKeyContainsFold ¶
JwtTokenKeyContainsFold applies the ContainsFold predicate on the "jwt_token_key" field.
func JwtTokenKeyEQ ¶
JwtTokenKeyEQ applies the EQ predicate on the "jwt_token_key" field.
func JwtTokenKeyEqualFold ¶
JwtTokenKeyEqualFold applies the EqualFold predicate on the "jwt_token_key" field.
func JwtTokenKeyGT ¶
JwtTokenKeyGT applies the GT predicate on the "jwt_token_key" field.
func JwtTokenKeyGTE ¶
JwtTokenKeyGTE applies the GTE predicate on the "jwt_token_key" field.
func JwtTokenKeyHasPrefix ¶
JwtTokenKeyHasPrefix applies the HasPrefix predicate on the "jwt_token_key" field.
func JwtTokenKeyHasSuffix ¶
JwtTokenKeyHasSuffix applies the HasSuffix predicate on the "jwt_token_key" field.
func JwtTokenKeyIn ¶
JwtTokenKeyIn applies the In predicate on the "jwt_token_key" field.
func JwtTokenKeyIsNil ¶
JwtTokenKeyIsNil applies the IsNil predicate on the "jwt_token_key" field.
func JwtTokenKeyLT ¶
JwtTokenKeyLT applies the LT predicate on the "jwt_token_key" field.
func JwtTokenKeyLTE ¶
JwtTokenKeyLTE applies the LTE predicate on the "jwt_token_key" field.
func JwtTokenKeyNEQ ¶
JwtTokenKeyNEQ applies the NEQ predicate on the "jwt_token_key" field.
func JwtTokenKeyNotIn ¶
JwtTokenKeyNotIn applies the NotIn predicate on the "jwt_token_key" field.
func JwtTokenKeyNotNil ¶
JwtTokenKeyNotNil applies the NotNil predicate on the "jwt_token_key" field.
func LastName ¶
LastName applies equality check predicate on the "last_name" field. It's identical to LastNameEQ.
func LastNameContains ¶
LastNameContains applies the Contains predicate on the "last_name" field.
func LastNameContainsFold ¶
LastNameContainsFold applies the ContainsFold predicate on the "last_name" field.
func LastNameEQ ¶
LastNameEQ applies the EQ predicate on the "last_name" field.
func LastNameEqualFold ¶
LastNameEqualFold applies the EqualFold predicate on the "last_name" field.
func LastNameGT ¶
LastNameGT applies the GT predicate on the "last_name" field.
func LastNameGTE ¶
LastNameGTE applies the GTE predicate on the "last_name" field.
func LastNameHasPrefix ¶
LastNameHasPrefix applies the HasPrefix predicate on the "last_name" field.
func LastNameHasSuffix ¶
LastNameHasSuffix applies the HasSuffix predicate on the "last_name" field.
func LastNameIn ¶
LastNameIn applies the In predicate on the "last_name" field.
func LastNameIsNil ¶
LastNameIsNil applies the IsNil predicate on the "last_name" field.
func LastNameLT ¶
LastNameLT applies the LT predicate on the "last_name" field.
func LastNameLTE ¶
LastNameLTE applies the LTE predicate on the "last_name" field.
func LastNameNEQ ¶
LastNameNEQ applies the NEQ predicate on the "last_name" field.
func LastNameNotIn ¶
LastNameNotIn applies the NotIn predicate on the "last_name" field.
func LastNameNotNil ¶
LastNameNotNil applies the NotNil predicate on the "last_name" field.
func Password ¶
Password applies equality check predicate on the "password" field. It's identical to PasswordEQ.
func PasswordContains ¶
PasswordContains applies the Contains predicate on the "password" field.
func PasswordContainsFold ¶
PasswordContainsFold applies the ContainsFold predicate on the "password" field.
func PasswordEQ ¶
PasswordEQ applies the EQ predicate on the "password" field.
func PasswordEqualFold ¶
PasswordEqualFold applies the EqualFold predicate on the "password" field.
func PasswordGT ¶
PasswordGT applies the GT predicate on the "password" field.
func PasswordGTE ¶
PasswordGTE applies the GTE predicate on the "password" field.
func PasswordHasPrefix ¶
PasswordHasPrefix applies the HasPrefix predicate on the "password" field.
func PasswordHasSuffix ¶
PasswordHasSuffix applies the HasSuffix predicate on the "password" field.
func PasswordIn ¶
PasswordIn applies the In predicate on the "password" field.
func PasswordIsNil ¶
PasswordIsNil applies the IsNil predicate on the "password" field.
func PasswordLT ¶
PasswordLT applies the LT predicate on the "password" field.
func PasswordLTE ¶
PasswordLTE applies the LTE predicate on the "password" field.
func PasswordNEQ ¶
PasswordNEQ applies the NEQ predicate on the "password" field.
func PasswordNotIn ¶
PasswordNotIn applies the NotIn predicate on the "password" field.
func PasswordNotNil ¶
PasswordNotNil applies the NotNil predicate on the "password" field.
func PhoneNumber ¶
PhoneNumber applies equality check predicate on the "phone_number" field. It's identical to PhoneNumberEQ.
func PhoneNumberContains ¶
PhoneNumberContains applies the Contains predicate on the "phone_number" field.
func PhoneNumberContainsFold ¶
PhoneNumberContainsFold applies the ContainsFold predicate on the "phone_number" field.
func PhoneNumberEQ ¶
PhoneNumberEQ applies the EQ predicate on the "phone_number" field.
func PhoneNumberEqualFold ¶
PhoneNumberEqualFold applies the EqualFold predicate on the "phone_number" field.
func PhoneNumberGT ¶
PhoneNumberGT applies the GT predicate on the "phone_number" field.
func PhoneNumberGTE ¶
PhoneNumberGTE applies the GTE predicate on the "phone_number" field.
func PhoneNumberHasPrefix ¶
PhoneNumberHasPrefix applies the HasPrefix predicate on the "phone_number" field.
func PhoneNumberHasSuffix ¶
PhoneNumberHasSuffix applies the HasSuffix predicate on the "phone_number" field.
func PhoneNumberIn ¶
PhoneNumberIn applies the In predicate on the "phone_number" field.
func PhoneNumberLT ¶
PhoneNumberLT applies the LT predicate on the "phone_number" field.
func PhoneNumberLTE ¶
PhoneNumberLTE applies the LTE predicate on the "phone_number" field.
func PhoneNumberNEQ ¶
PhoneNumberNEQ applies the NEQ predicate on the "phone_number" field.
func PhoneNumberNotIn ¶
PhoneNumberNotIn applies the NotIn predicate on the "phone_number" field.
func UpdateTime ¶
UpdateTime applies equality check predicate on the "update_time" field. It's identical to UpdateTimeEQ.
func UpdateTimeEQ ¶
UpdateTimeEQ applies the EQ predicate on the "update_time" field.
func UpdateTimeGT ¶
UpdateTimeGT applies the GT predicate on the "update_time" field.
func UpdateTimeGTE ¶
UpdateTimeGTE applies the GTE predicate on the "update_time" field.
func UpdateTimeIn ¶
UpdateTimeIn applies the In predicate on the "update_time" field.
func UpdateTimeLT ¶
UpdateTimeLT applies the LT predicate on the "update_time" field.
func UpdateTimeLTE ¶
UpdateTimeLTE applies the LTE predicate on the "update_time" field.
func UpdateTimeNEQ ¶
UpdateTimeNEQ applies the NEQ predicate on the "update_time" field.
func UpdateTimeNotIn ¶
UpdateTimeNotIn applies the NotIn predicate on the "update_time" field.
func Username ¶
Username applies equality check predicate on the "username" field. It's identical to UsernameEQ.
func UsernameContains ¶
UsernameContains applies the Contains predicate on the "username" field.
func UsernameContainsFold ¶
UsernameContainsFold applies the ContainsFold predicate on the "username" field.
func UsernameEQ ¶
UsernameEQ applies the EQ predicate on the "username" field.
func UsernameEqualFold ¶
UsernameEqualFold applies the EqualFold predicate on the "username" field.
func UsernameGT ¶
UsernameGT applies the GT predicate on the "username" field.
func UsernameGTE ¶
UsernameGTE applies the GTE predicate on the "username" field.
func UsernameHasPrefix ¶
UsernameHasPrefix applies the HasPrefix predicate on the "username" field.
func UsernameHasSuffix ¶
UsernameHasSuffix applies the HasSuffix predicate on the "username" field.
func UsernameIn ¶
UsernameIn applies the In predicate on the "username" field.
func UsernameLT ¶
UsernameLT applies the LT predicate on the "username" field.
func UsernameLTE ¶
UsernameLTE applies the LTE predicate on the "username" field.
func UsernameNEQ ¶
UsernameNEQ applies the NEQ predicate on the "username" field.
func UsernameNotIn ¶
UsernameNotIn applies the NotIn predicate on the "username" field.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
Types ¶
This section is empty.