Documentation
¶
Index ¶
- Constants
- Variables
- func APIKey(v string) predicate.Partner
- func APIKeyContains(v string) predicate.Partner
- func APIKeyContainsFold(v string) predicate.Partner
- func APIKeyEQ(v string) predicate.Partner
- func APIKeyEqualFold(v string) predicate.Partner
- func APIKeyGT(v string) predicate.Partner
- func APIKeyGTE(v string) predicate.Partner
- func APIKeyHasPrefix(v string) predicate.Partner
- func APIKeyHasSuffix(v string) predicate.Partner
- func APIKeyIn(vs ...string) predicate.Partner
- func APIKeyLT(v string) predicate.Partner
- func APIKeyLTE(v string) predicate.Partner
- func APIKeyNEQ(v string) predicate.Partner
- func APIKeyNotIn(vs ...string) predicate.Partner
- func And(predicates ...predicate.Partner) predicate.Partner
- func CreateTime(v time.Time) predicate.Partner
- func CreateTimeEQ(v time.Time) predicate.Partner
- func CreateTimeGT(v time.Time) predicate.Partner
- func CreateTimeGTE(v time.Time) predicate.Partner
- func CreateTimeIn(vs ...time.Time) predicate.Partner
- func CreateTimeLT(v time.Time) predicate.Partner
- func CreateTimeLTE(v time.Time) predicate.Partner
- func CreateTimeNEQ(v time.Time) predicate.Partner
- func CreateTimeNotIn(vs ...time.Time) predicate.Partner
- func ID(id uuid.UUID) predicate.Partner
- func IDEQ(id uuid.UUID) predicate.Partner
- func IDGT(id uuid.UUID) predicate.Partner
- func IDGTE(id uuid.UUID) predicate.Partner
- func IDIn(ids ...uuid.UUID) predicate.Partner
- func IDLT(id uuid.UUID) predicate.Partner
- func IDLTE(id uuid.UUID) predicate.Partner
- func IDNEQ(id uuid.UUID) predicate.Partner
- func IDNotIn(ids ...uuid.UUID) predicate.Partner
- func IsActive(v bool) predicate.Partner
- func IsActiveEQ(v bool) predicate.Partner
- func IsActiveIsNil() predicate.Partner
- func IsActiveNEQ(v bool) predicate.Partner
- func IsActiveNotNil() predicate.Partner
- func Name(v string) predicate.Partner
- func NameContains(v string) predicate.Partner
- func NameContainsFold(v string) predicate.Partner
- func NameEQ(v string) predicate.Partner
- func NameEqualFold(v string) predicate.Partner
- func NameGT(v string) predicate.Partner
- func NameGTE(v string) predicate.Partner
- func NameHasPrefix(v string) predicate.Partner
- func NameHasSuffix(v string) predicate.Partner
- func NameIn(vs ...string) predicate.Partner
- func NameIsNil() predicate.Partner
- func NameLT(v string) predicate.Partner
- func NameLTE(v string) predicate.Partner
- func NameNEQ(v string) predicate.Partner
- func NameNotIn(vs ...string) predicate.Partner
- func NameNotNil() predicate.Partner
- func Not(p predicate.Partner) predicate.Partner
- func Or(predicates ...predicate.Partner) predicate.Partner
- func PrivateKey(v string) predicate.Partner
- func PrivateKeyContains(v string) predicate.Partner
- func PrivateKeyContainsFold(v string) predicate.Partner
- func PrivateKeyEQ(v string) predicate.Partner
- func PrivateKeyEqualFold(v string) predicate.Partner
- func PrivateKeyGT(v string) predicate.Partner
- func PrivateKeyGTE(v string) predicate.Partner
- func PrivateKeyHasPrefix(v string) predicate.Partner
- func PrivateKeyHasSuffix(v string) predicate.Partner
- func PrivateKeyIn(vs ...string) predicate.Partner
- func PrivateKeyLT(v string) predicate.Partner
- func PrivateKeyLTE(v string) predicate.Partner
- func PrivateKeyNEQ(v string) predicate.Partner
- func PrivateKeyNotIn(vs ...string) predicate.Partner
- func PublicKey(v string) predicate.Partner
- func PublicKeyContains(v string) predicate.Partner
- func PublicKeyContainsFold(v string) predicate.Partner
- func PublicKeyEQ(v string) predicate.Partner
- func PublicKeyEqualFold(v string) predicate.Partner
- func PublicKeyGT(v string) predicate.Partner
- func PublicKeyGTE(v string) predicate.Partner
- func PublicKeyHasPrefix(v string) predicate.Partner
- func PublicKeyHasSuffix(v string) predicate.Partner
- func PublicKeyIn(vs ...string) predicate.Partner
- func PublicKeyLT(v string) predicate.Partner
- func PublicKeyLTE(v string) predicate.Partner
- func PublicKeyNEQ(v string) predicate.Partner
- func PublicKeyNotIn(vs ...string) predicate.Partner
- func SecretKey(v string) predicate.Partner
- func SecretKeyContains(v string) predicate.Partner
- func SecretKeyContainsFold(v string) predicate.Partner
- func SecretKeyEQ(v string) predicate.Partner
- func SecretKeyEqualFold(v string) predicate.Partner
- func SecretKeyGT(v string) predicate.Partner
- func SecretKeyGTE(v string) predicate.Partner
- func SecretKeyHasPrefix(v string) predicate.Partner
- func SecretKeyHasSuffix(v string) predicate.Partner
- func SecretKeyIn(vs ...string) predicate.Partner
- func SecretKeyLT(v string) predicate.Partner
- func SecretKeyLTE(v string) predicate.Partner
- func SecretKeyNEQ(v string) predicate.Partner
- func SecretKeyNotIn(vs ...string) predicate.Partner
- func UpdateTime(v time.Time) predicate.Partner
- func UpdateTimeEQ(v time.Time) predicate.Partner
- func UpdateTimeGT(v time.Time) predicate.Partner
- func UpdateTimeGTE(v time.Time) predicate.Partner
- func UpdateTimeIn(vs ...time.Time) predicate.Partner
- func UpdateTimeLT(v time.Time) predicate.Partner
- func UpdateTimeLTE(v time.Time) predicate.Partner
- func UpdateTimeNEQ(v time.Time) predicate.Partner
- func UpdateTimeNotIn(vs ...time.Time) predicate.Partner
- func ValidColumn(column string) bool
Constants ¶
const ( // Label holds the string label denoting the partner type in the database. Label = "partner" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldCreateTime holds the string denoting the create_time field in the database. FieldCreateTime = "create_time" // FieldUpdateTime holds the string denoting the update_time field in the database. FieldUpdateTime = "update_time" // FieldAPIKey holds the string denoting the api_key field in the database. FieldAPIKey = "api_key" // FieldSecretKey holds the string denoting the secret_key field in the database. FieldSecretKey = "secret_key" // FieldPublicKey holds the string denoting the public_key field in the database. FieldPublicKey = "public_key" // FieldPrivateKey holds the string denoting the private_key field in the database. FieldPrivateKey = "private_key" // FieldName holds the string denoting the name field in the database. FieldName = "name" // FieldIsActive holds the string denoting the is_active field in the database. FieldIsActive = "is_active" // Table holds the table name of the partner in the database. Table = "partners" )
Variables ¶
var ( // DefaultCreateTime holds the default value on creation for the "create_time" field. DefaultCreateTime func() time.Time // DefaultUpdateTime holds the default value on creation for the "update_time" field. DefaultUpdateTime func() time.Time // UpdateDefaultUpdateTime holds the default value on update for the "update_time" field. UpdateDefaultUpdateTime func() time.Time // DefaultName holds the default value on creation for the "name" field. DefaultName string // NameValidator is a validator for the "name" field. It is called by the builders before save. NameValidator func(string) error // DefaultIsActive holds the default value on creation for the "is_active" field. DefaultIsActive bool // DefaultID holds the default value on creation for the "id" field. DefaultID func() uuid.UUID )
var Columns = []string{ FieldID, FieldCreateTime, FieldUpdateTime, FieldAPIKey, FieldSecretKey, FieldPublicKey, FieldPrivateKey, FieldName, FieldIsActive, }
Columns holds all SQL columns for partner fields.
Functions ¶
func APIKey ¶
APIKey applies equality check predicate on the "api_key" field. It's identical to APIKeyEQ.
func APIKeyContains ¶
APIKeyContains applies the Contains predicate on the "api_key" field.
func APIKeyContainsFold ¶
APIKeyContainsFold applies the ContainsFold predicate on the "api_key" field.
func APIKeyEqualFold ¶
APIKeyEqualFold applies the EqualFold predicate on the "api_key" field.
func APIKeyHasPrefix ¶
APIKeyHasPrefix applies the HasPrefix predicate on the "api_key" field.
func APIKeyHasSuffix ¶
APIKeyHasSuffix applies the HasSuffix predicate on the "api_key" field.
func APIKeyNotIn ¶
APIKeyNotIn applies the NotIn predicate on the "api_key" field.
func CreateTime ¶
CreateTime applies equality check predicate on the "create_time" field. It's identical to CreateTimeEQ.
func CreateTimeEQ ¶
CreateTimeEQ applies the EQ predicate on the "create_time" field.
func CreateTimeGT ¶
CreateTimeGT applies the GT predicate on the "create_time" field.
func CreateTimeGTE ¶
CreateTimeGTE applies the GTE predicate on the "create_time" field.
func CreateTimeIn ¶
CreateTimeIn applies the In predicate on the "create_time" field.
func CreateTimeLT ¶
CreateTimeLT applies the LT predicate on the "create_time" field.
func CreateTimeLTE ¶
CreateTimeLTE applies the LTE predicate on the "create_time" field.
func CreateTimeNEQ ¶
CreateTimeNEQ applies the NEQ predicate on the "create_time" field.
func CreateTimeNotIn ¶
CreateTimeNotIn applies the NotIn predicate on the "create_time" field.
func IsActive ¶
IsActive applies equality check predicate on the "is_active" field. It's identical to IsActiveEQ.
func IsActiveEQ ¶
IsActiveEQ applies the EQ predicate on the "is_active" field.
func IsActiveIsNil ¶
IsActiveIsNil applies the IsNil predicate on the "is_active" field.
func IsActiveNEQ ¶
IsActiveNEQ applies the NEQ predicate on the "is_active" field.
func IsActiveNotNil ¶
IsActiveNotNil applies the NotNil predicate on the "is_active" field.
func NameContains ¶
NameContains applies the Contains predicate on the "name" field.
func NameContainsFold ¶
NameContainsFold applies the ContainsFold predicate on the "name" field.
func NameEqualFold ¶
NameEqualFold applies the EqualFold predicate on the "name" field.
func NameHasPrefix ¶
NameHasPrefix applies the HasPrefix predicate on the "name" field.
func NameHasSuffix ¶
NameHasSuffix applies the HasSuffix predicate on the "name" field.
func NameNotNil ¶
NameNotNil applies the NotNil predicate on the "name" field.
func PrivateKey ¶
PrivateKey applies equality check predicate on the "private_key" field. It's identical to PrivateKeyEQ.
func PrivateKeyContains ¶
PrivateKeyContains applies the Contains predicate on the "private_key" field.
func PrivateKeyContainsFold ¶
PrivateKeyContainsFold applies the ContainsFold predicate on the "private_key" field.
func PrivateKeyEQ ¶
PrivateKeyEQ applies the EQ predicate on the "private_key" field.
func PrivateKeyEqualFold ¶
PrivateKeyEqualFold applies the EqualFold predicate on the "private_key" field.
func PrivateKeyGT ¶
PrivateKeyGT applies the GT predicate on the "private_key" field.
func PrivateKeyGTE ¶
PrivateKeyGTE applies the GTE predicate on the "private_key" field.
func PrivateKeyHasPrefix ¶
PrivateKeyHasPrefix applies the HasPrefix predicate on the "private_key" field.
func PrivateKeyHasSuffix ¶
PrivateKeyHasSuffix applies the HasSuffix predicate on the "private_key" field.
func PrivateKeyIn ¶
PrivateKeyIn applies the In predicate on the "private_key" field.
func PrivateKeyLT ¶
PrivateKeyLT applies the LT predicate on the "private_key" field.
func PrivateKeyLTE ¶
PrivateKeyLTE applies the LTE predicate on the "private_key" field.
func PrivateKeyNEQ ¶
PrivateKeyNEQ applies the NEQ predicate on the "private_key" field.
func PrivateKeyNotIn ¶
PrivateKeyNotIn applies the NotIn predicate on the "private_key" field.
func PublicKey ¶
PublicKey applies equality check predicate on the "public_key" field. It's identical to PublicKeyEQ.
func PublicKeyContains ¶
PublicKeyContains applies the Contains predicate on the "public_key" field.
func PublicKeyContainsFold ¶
PublicKeyContainsFold applies the ContainsFold predicate on the "public_key" field.
func PublicKeyEQ ¶
PublicKeyEQ applies the EQ predicate on the "public_key" field.
func PublicKeyEqualFold ¶
PublicKeyEqualFold applies the EqualFold predicate on the "public_key" field.
func PublicKeyGT ¶
PublicKeyGT applies the GT predicate on the "public_key" field.
func PublicKeyGTE ¶
PublicKeyGTE applies the GTE predicate on the "public_key" field.
func PublicKeyHasPrefix ¶
PublicKeyHasPrefix applies the HasPrefix predicate on the "public_key" field.
func PublicKeyHasSuffix ¶
PublicKeyHasSuffix applies the HasSuffix predicate on the "public_key" field.
func PublicKeyIn ¶
PublicKeyIn applies the In predicate on the "public_key" field.
func PublicKeyLT ¶
PublicKeyLT applies the LT predicate on the "public_key" field.
func PublicKeyLTE ¶
PublicKeyLTE applies the LTE predicate on the "public_key" field.
func PublicKeyNEQ ¶
PublicKeyNEQ applies the NEQ predicate on the "public_key" field.
func PublicKeyNotIn ¶
PublicKeyNotIn applies the NotIn predicate on the "public_key" field.
func SecretKey ¶
SecretKey applies equality check predicate on the "secret_key" field. It's identical to SecretKeyEQ.
func SecretKeyContains ¶
SecretKeyContains applies the Contains predicate on the "secret_key" field.
func SecretKeyContainsFold ¶
SecretKeyContainsFold applies the ContainsFold predicate on the "secret_key" field.
func SecretKeyEQ ¶
SecretKeyEQ applies the EQ predicate on the "secret_key" field.
func SecretKeyEqualFold ¶
SecretKeyEqualFold applies the EqualFold predicate on the "secret_key" field.
func SecretKeyGT ¶
SecretKeyGT applies the GT predicate on the "secret_key" field.
func SecretKeyGTE ¶
SecretKeyGTE applies the GTE predicate on the "secret_key" field.
func SecretKeyHasPrefix ¶
SecretKeyHasPrefix applies the HasPrefix predicate on the "secret_key" field.
func SecretKeyHasSuffix ¶
SecretKeyHasSuffix applies the HasSuffix predicate on the "secret_key" field.
func SecretKeyIn ¶
SecretKeyIn applies the In predicate on the "secret_key" field.
func SecretKeyLT ¶
SecretKeyLT applies the LT predicate on the "secret_key" field.
func SecretKeyLTE ¶
SecretKeyLTE applies the LTE predicate on the "secret_key" field.
func SecretKeyNEQ ¶
SecretKeyNEQ applies the NEQ predicate on the "secret_key" field.
func SecretKeyNotIn ¶
SecretKeyNotIn applies the NotIn predicate on the "secret_key" field.
func UpdateTime ¶
UpdateTime applies equality check predicate on the "update_time" field. It's identical to UpdateTimeEQ.
func UpdateTimeEQ ¶
UpdateTimeEQ applies the EQ predicate on the "update_time" field.
func UpdateTimeGT ¶
UpdateTimeGT applies the GT predicate on the "update_time" field.
func UpdateTimeGTE ¶
UpdateTimeGTE applies the GTE predicate on the "update_time" field.
func UpdateTimeIn ¶
UpdateTimeIn applies the In predicate on the "update_time" field.
func UpdateTimeLT ¶
UpdateTimeLT applies the LT predicate on the "update_time" field.
func UpdateTimeLTE ¶
UpdateTimeLTE applies the LTE predicate on the "update_time" field.
func UpdateTimeNEQ ¶
UpdateTimeNEQ applies the NEQ predicate on the "update_time" field.
func UpdateTimeNotIn ¶
UpdateTimeNotIn applies the NotIn predicate on the "update_time" field.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
Types ¶
This section is empty.